/**
 * This declaration file requires TypeScript 2.1 or above.
 */

declare namespace Bitbucket {
  export type Any = any;
  export type AnyObject = object;

  export type Headers = {
    [header: string]: any
  };

  export interface Options {
    baseUrl?: string;
    headers?: Headers;
    options?: AnyObject;
    hideNotice?: boolean;
  }

  interface AuthBasic {
    type: "basic";
    username: string;
    password: string;
  }

  interface AuthAppPassword {
    type: "apppassword";
    username: string;
    password: string;
  }

  interface AuthToken {
    type: "token";
    token: string;
  }

  export type Auth =
    | AuthBasic
    | AuthAppPassword
    | AuthToken;

  export type PaginatedData =
    | { next: string; }
    | { previous: string; };

  export interface Callback<T> {
    (error: Bitbucket.Schema.Error | null, response: T): void;
  }

  export interface Response<T> {
    data: T;
    headers: Headers;
  }

  namespace Schema {
    export type Any = Bitbucket.Any;

    export type Branch = Ref & {
      [k: string]: any;
    };
    export type Commit = BaseCommit & {
      participants?: Participant[];
      repository?: Repository;
      [k: string]: any;
    };
    export type BaseCommit = Object & {
      author?: Author;
      date?: string;
      hash?: string;
      message?: string;
      parents?: BaseCommit[];
      summary?: {
        html?: string;
        markup?: "markdown" | "creole" | "plaintext";
        raw?: string;
      };
      [k: string]: any;
    };
    export type Author = Object & {
      raw?: string;
      user?: Account;
      [k: string]: any;
    };
    export type Account = Object & {
      account_status?: string;
      created_on?: string;
      display_name?: string;
      has_2fa_enabled?: boolean;
      links?: {
        avatar?: {
          href?: string;
          name?: string;
        };
        followers?: {
          href?: string;
          name?: string;
        };
        following?: {
          href?: string;
          name?: string;
        };
        html?: {
          href?: string;
          name?: string;
        };
        repositories?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
      };
      nickname?: string;
      username?: string;
      uuid?: string;
      website?: string;
      [k: string]: any;
    };
    export type Participant = Object & {
      approved?: boolean;
      participated_on?: string;
      role?: "PARTICIPANT" | "REVIEWER";
      user?: User;
      [k: string]: any;
    };
    export type User = Account & {
      account_id?: string;
      is_staff?: boolean;
      [k: string]: any;
    };
    export type Repository = Object & {
      created_on?: string;
      description?: string;
      fork_policy?: "allow_forks" | "no_public_forks" | "no_forks";
      full_name?: string;
      has_issues?: boolean;
      has_wiki?: boolean;
      is_private?: boolean;
      language?: string;
      links?: {
        avatar?: {
          href?: string;
          name?: string;
        };
        clone?: {
          href?: string;
          name?: string;
        }[];
        commits?: {
          href?: string;
          name?: string;
        };
        downloads?: {
          href?: string;
          name?: string;
        };
        forks?: {
          href?: string;
          name?: string;
        };
        hooks?: {
          href?: string;
          name?: string;
        };
        html?: {
          href?: string;
          name?: string;
        };
        pullrequests?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
        watchers?: {
          href?: string;
          name?: string;
        };
      };
      mainbranch?: Branch;
      name?: string;
      owner?: Account;
      parent?: Repository;
      project?: Project;
      scm?: "hg" | "git";
      size?: number;
      updated_on?: string;
      uuid?: string;
      [k: string]: any;
    };
    export type Project = Object & {
      created_on?: string;
      description?: string;
      is_private?: boolean;
      key?: string;
      links?: {
        avatar?: {
          href?: string;
          name?: string;
        };
        html?: {
          href?: string;
          name?: string;
        };
      };
      name?: string;
      owner?: Team;
      updated_on?: string;
      uuid?: string;
      [k: string]: any;
    };
    export type Team = Account & {
      [k: string]: any;
    };
    export type BranchingModel = Object & {
      branch_types?: {
        kind: "feature" | "bugfix" | "release" | "hotfix";
        prefix: string;
      }[];
      development?: {
        branch?: Branch;
        name: string;
        use_mainbranch: boolean;
      };
      production?: {
        branch?: Branch;
        name: string;
        use_mainbranch: boolean;
      };
      [k: string]: any;
    };
    export type BranchingModelSettings = Object & {
      branch_types?: {
        enabled?: boolean;
        kind: "feature" | "bugfix" | "release" | "hotfix";
        prefix?: string;
      }[];
      development?: {
        is_valid?: boolean;
        name?: string;
        use_mainbranch?: boolean;
      };
      links?: {
        self?: {
          href?: string;
          name?: string;
        };
      };
      production?: {
        enabled?: boolean;
        is_valid?: boolean;
        name?: string;
        use_mainbranch?: boolean;
      };
      [k: string]: any;
    };
    export type Branchrestriction = Object & {
      branch_match_kind: "branching_model" | "glob";
      branch_type?: "feature" | "bugfix" | "release" | "hotfix" | "development" | "production";
      groups?: Group[];
      id?: number;
      kind:
        | "require_tasks_to_be_completed"
        | "force"
        | "restrict_merges"
        | "enforce_merge_checks"
        | "require_approvals_to_merge"
        | "delete"
        | "require_all_dependencies_merged"
        | "push"
        | "require_passing_builds_to_merge"
        | "reset_pullrequest_approvals_on_change"
        | "require_default_reviewer_approvals_to_merge";
      links?: {
        self?: {
          href?: string;
          name?: string;
        };
      };
      pattern: string;
      users?: Account[];
      value?: number;
      [k: string]: any;
    };
    export type Group = Object & {
      full_slug?: string;
      links?: {
        html?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
      };
      members?: number;
      name?: string;
      owner?: Account;
      slug?: string;
      [k: string]: any;
    };
    export type CommitComment = Comment & {
      commit?: Commit;
      [k: string]: any;
    };
    export type Comment = Object & {
      content?: {
        html?: string;
        markup?: "markdown" | "creole" | "plaintext";
        raw?: string;
      };
      created_on?: string;
      deleted?: boolean;
      id?: number;
      inline?: {
        from?: number;
        path: string;
        to?: number;
      };
      links?: {
        code?: {
          href?: string;
          name?: string;
        };
        html?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
      };
      parent?: Comment;
      updated_on?: string;
      user?: User;
      [k: string]: any;
    };
    export type Commitstatus = Object & {
      created_on?: string;
      description?: string;
      key?: string;
      links?: {
        commit?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
      };
      name?: string;
      refname?: string;
      state?: "SUCCESSFUL" | "FAILED" | "INPROGRESS" | "STOPPED";
      updated_on?: string;
      url?: string;
      uuid?: string;
      [k: string]: any;
    };
    export type Component = Object & {
      id?: number;
      links?: {
        self?: {
          href?: string;
          name?: string;
        };
      };
      name?: string;
      [k: string]: any;
    };
    export type DeployKey = Object & {
      added_on?: string;
      comment?: string;
      key?: string;
      label?: string;
      last_used?: string;
      links?: {
        self?: {
          href?: string;
          name?: string;
        };
      };
      owner?: Account;
      repository?: Repository;
      [k: string]: any;
    };
    export type Deployment = Object & {
      environment?: DeploymentEnvironment;
      release?: DeploymentRelease;
      state?: DeploymentState;
      uuid?: string;
      [k: string]: any;
    };
    export type DeploymentEnvironment = Object & {
      name?: string;
      uuid?: string;
      [k: string]: any;
    };
    export type DeploymentRelease = Object & {
      commit?: Commit;
      created_on?: string;
      name?: string;
      url?: string;
      uuid?: string;
      [k: string]: any;
    };
    export type DeploymentState = Object & {
      [k: string]: any;
    };
    export type DeploymentVariable = Object & {
      key?: string;
      secured?: boolean;
      uuid?: string;
      value?: string;
      [k: string]: any;
    };
    export type Issue = Object & {
      assignee?: User;
      component?: Component;
      content?: {
        html?: string;
        markup?: "markdown" | "creole" | "plaintext";
        raw?: string;
      };
      created_on?: string;
      edited_on?: string;
      id?: number;
      kind?: "bug" | "enhancement" | "proposal" | "task";
      links?: {
        attachments?: {
          href?: string;
          name?: string;
        };
        comments?: {
          href?: string;
          name?: string;
        };
        html?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
        vote?: {
          href?: string;
          name?: string;
        };
        watch?: {
          href?: string;
          name?: string;
        };
      };
      milestone?: Milestone;
      priority?: "trivial" | "minor" | "major" | "critical" | "blocker";
      reporter?: User;
      repository?: Repository;
      state?: "new" | "open" | "resolved" | "on hold" | "invalid" | "duplicate" | "wontfix" | "closed";
      title?: string;
      updated_on?: string;
      version?: Version;
      votes?: number;
      [k: string]: any;
    };
    export type Milestone = Object & {
      id?: number;
      links?: {
        self?: {
          href?: string;
          name?: string;
        };
      };
      name?: string;
      [k: string]: any;
    };
    export type Version = Object & {
      id?: number;
      links?: {
        self?: {
          href?: string;
          name?: string;
        };
      };
      name?: string;
      [k: string]: any;
    };
    export type IssueComment = Comment & {
      issue?: Issue;
      [k: string]: any;
    };
    export type IssueAttachment = Object & {
      links?: {
        self?: {
          href?: string;
          name?: string;
        };
      };
      name?: string;
      [k: string]: any;
    };
    export type PipelineKnownHost = Object & {
      hostname?: string;
      public_key?: PipelineSshPublicKey;
      uuid?: string;
      [k: string]: any;
    };
    export type PipelineSshPublicKey = Object & {
      key?: string;
      key_type?: string;
      md5_fingerprint?: string;
      sha256_fingerprint?: string;
      [k: string]: any;
    };
    export type PipelineScheduleExecution = Object & {
      [k: string]: any;
    };
    export type PipelineSchedule = Object & {
      created_on?: string;
      cron_pattern?: string;
      enabled?: boolean;
      selector?: PipelineSelector;
      target?: PipelineTarget;
      updated_on?: string;
      uuid?: string;
      [k: string]: any;
    };
    export type PipelineSelector = Object & {
      pattern?: string;
      type?: "branches" | "tags" | "bookmarks" | "default" | "custom";
      [k: string]: any;
    };
    export type PipelineTarget = Object & {
      [k: string]: any;
    };
    export type PipelineStep = Object & {
      completed_on?: string;
      image?: PipelineImage;
      script_commands?: PipelineCommand[];
      setup_commands?: PipelineCommand[];
      started_on?: string;
      state?: PipelineStepState;
      uuid?: string;
      [k: string]: any;
    };
    export type PipelineStepState = Object & {
      [k: string]: any;
    };
    export type PipelineVariable = Object & {
      key?: string;
      secured?: boolean;
      uuid?: string;
      value?: string;
      [k: string]: any;
    };
    export type Pipeline = Object & {
      build_number?: number;
      build_seconds_used?: number;
      completed_on?: string;
      created_on?: string;
      creator?: Account;
      repository?: Repository;
      state?: PipelineState;
      target?: PipelineTarget;
      trigger?: PipelineTrigger;
      uuid?: string;
      [k: string]: any;
    };
    export type PipelineState = Object & {
      [k: string]: any;
    };
    export type PipelineTrigger = Object & {
      [k: string]: any;
    };
    export type PullrequestComment = Comment & {
      pullrequest?: Pullrequest;
      [k: string]: any;
    };
    export type Pullrequest = Object & {
      author?: Account;
      close_source_branch?: boolean;
      closed_by?: Account;
      comment_count?: number;
      created_on?: string;
      destination?: PullrequestEndpoint;
      id?: number;
      links?: {
        activity?: {
          href?: string;
          name?: string;
        };
        approve?: {
          href?: string;
          name?: string;
        };
        comments?: {
          href?: string;
          name?: string;
        };
        commits?: {
          href?: string;
          name?: string;
        };
        decline?: {
          href?: string;
          name?: string;
        };
        diff?: {
          href?: string;
          name?: string;
        };
        diffstat?: {
          href?: string;
          name?: string;
        };
        html?: {
          href?: string;
          name?: string;
        };
        merge?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
      };
      merge_commit?: {
        hash?: string;
      };
      participants?: Participant[];
      reason?: string;
      rendered?: {
        description?: {
          html?: string;
          markup?: "markdown" | "creole" | "plaintext";
          raw?: string;
        };
        reason?: {
          html?: string;
          markup?: "markdown" | "creole" | "plaintext";
          raw?: string;
        };
        title?: {
          html?: string;
          markup?: "markdown" | "creole" | "plaintext";
          raw?: string;
        };
      };
      reviewers?: Account[];
      source?: PullrequestEndpoint;
      state?: "MERGED" | "SUPERSEDED" | "OPEN" | "DECLINED";
      summary?: {
        html?: string;
        markup?: "markdown" | "creole" | "plaintext";
        raw?: string;
      };
      task_count?: number;
      title?: string;
      updated_on?: string;
      [k: string]: any;
    };
    export type SnippetComment = Object & {
      links?: {
        html?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
      };
      snippet?: Snippet;
      [k: string]: any;
    };
    export type Snippet = Object & {
      created_on?: string;
      creator?: Account;
      id?: number;
      is_private?: boolean;
      owner?: Account;
      scm?: "hg" | "git";
      title?: string;
      updated_on?: string;
      [k: string]: any;
    };
    export type SnippetCommit = BaseCommit & {
      links?: {
        diff?: {
          href?: string;
          name?: string;
        };
        html?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
      };
      snippet?: Snippet;
      [k: string]: any;
    };
    export type SshAccountKey = SshKey & {
      owner?: Account;
      [k: string]: any;
    };
    export type SshKey = Object & {
      comment?: string;
      created_on?: string;
      key?: string;
      label?: string;
      last_used?: string;
      links?: {
        self?: {
          href?: string;
          name?: string;
        };
      };
      uuid?: string;
      [k: string]: any;
    };
    export type Tag = Ref & {
      date?: string;
      message?: string;
      tagger?: Author;
      [k: string]: any;
    };
    export type WebhookSubscription = Object & {
      active?: boolean;
      created_at?: string;
      description?: string;
      events?: (
        | "pullrequest:unapproved"
        | "issue:comment_created"
        | "pullrequest:approved"
        | "repo:created"
        | "repo:deleted"
        | "repo:imported"
        | "pullrequest:comment_updated"
        | "issue:updated"
        | "project:updated"
        | "pullrequest:comment_created"
        | "repo:commit_status_updated"
        | "pullrequest:updated"
        | "issue:created"
        | "repo:fork"
        | "pullrequest:comment_deleted"
        | "repo:commit_status_created"
        | "repo:updated"
        | "pullrequest:rejected"
        | "pullrequest:fulfilled"
        | "repo:push"
        | "pullrequest:created"
        | "repo:transfer"
        | "repo:commit_comment_created")[];
      subject?: Object;
      subject_type?: "workspace" | "user" | "repository" | "team";
      url?: string;
      uuid?: string;
      [k: string]: any;
    };
    export type PipelineBuildNumber = Object & {
      next?: number;
      [k: string]: any;
    };
    export type PipelineSshKeyPair = Object & {
      private_key?: string;
      public_key?: string;
      [k: string]: any;
    };
    export type PipelinesConfig = Object & {
      enabled?: boolean;
      repository?: Repository;
      [k: string]: any;
    };
    export interface Ref {
      links?: {
        commits?: {
          href?: string;
          name?: string;
        };
        html?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
      };
      name?: string;
      target?: Commit;
      type: string;
      [k: string]: any;
    }
    export interface Object {
      type: string;
      [k: string]: any;
    }
    export interface Error {
      error?: {
        data?: {
          [k: string]: any;
        };
        detail?: string;
        message: string;
      };
      type: string;
      [k: string]: any;
    }
    export interface IssueChange {
      changes?: {
        assignee?: {
          new?: string;
          old?: string;
        };
        component?: {
          new?: string;
          old?: string;
        };
        content?: {
          new?: string;
          old?: string;
        };
        kind?: {
          new?: string;
          old?: string;
        };
        milestone?: {
          new?: string;
          old?: string;
        };
        priority?: {
          new?: string;
          old?: string;
        };
        state?: {
          new?: string;
          old?: string;
        };
        title?: {
          new?: string;
          old?: string;
        };
        version?: {
          new?: string;
          old?: string;
        };
      };
      created_on?: string;
      issue?: Issue;
      links?: {
        issue?: {
          href?: string;
          name?: string;
        };
        self?: {
          href?: string;
          name?: string;
        };
      };
      message?: {
        html?: string;
        markup?: "markdown" | "creole" | "plaintext";
        raw?: string;
      };
      name?: string;
      type: string;
      user?: User;
      [k: string]: any;
    }
    export interface IssueJobStatus {
      count?: number;
      pct?: number;
      phase?: string;
      status?: "ACCEPTED" | "STARTED" | "RUNNING" | "FAILURE";
      total?: number;
      type?: string;
    }
    export interface PaginatedBranches {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Branch[];
    }
    export interface PaginatedBranchrestrictions {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Branchrestriction[];
    }
    export interface PaginatedCommitComments {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: CommitComment[];
    }
    export interface PaginatedCommitstatuses {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Commitstatus[];
    }
    export interface PaginatedComponents {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Component[];
    }
    export interface PaginatedDeployKeys {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: DeployKey[];
    }
    export interface PaginatedDeploymentVariable {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: DeploymentVariable[];
      [k: string]: any;
    }
    export interface PaginatedDeployments {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Deployment[];
      [k: string]: any;
    }
    export interface PaginatedDiffstats {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Diffstat[];
    }
    export interface Diffstat {
      lines_added?: number;
      lines_removed?: number;
      new?: CommitFile;
      old?: CommitFile;
      status?: "added" | "removed" | "modified" | "renamed";
      type: string;
      [k: string]: any;
    }
    export interface CommitFile {
      attributes?: "link" | "executable" | "subrepository" | "binary" | "lfs";
      commit?: Commit;
      path?: string;
      type: string;
      [k: string]: any;
    }
    export interface PaginatedEnvironments {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: DeploymentEnvironment[];
      [k: string]: any;
    }
    export interface PaginatedFiles {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: CommitFile[];
    }
    export interface PaginatedHookEvents {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: HookEvent[];
    }
    export interface HookEvent {
      category?: string;
      description?: string;
      event?:
        | "pullrequest:unapproved"
        | "issue:comment_created"
        | "pullrequest:approved"
        | "repo:created"
        | "repo:deleted"
        | "repo:imported"
        | "pullrequest:comment_updated"
        | "issue:updated"
        | "project:updated"
        | "pullrequest:comment_created"
        | "repo:commit_status_updated"
        | "pullrequest:updated"
        | "issue:created"
        | "repo:fork"
        | "pullrequest:comment_deleted"
        | "repo:commit_status_created"
        | "repo:updated"
        | "pullrequest:rejected"
        | "pullrequest:fulfilled"
        | "repo:push"
        | "pullrequest:created"
        | "repo:transfer"
        | "repo:commit_comment_created";
      label?: string;
    }
    export interface PaginatedIssueAttachments {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: IssueAttachment[];
    }
    export interface PaginatedIssueComments {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: IssueComment[];
    }
    export interface PaginatedIssues {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Issue[];
    }
    export interface PaginatedLogEntries {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: IssueChange[];
    }
    export interface PaginatedMilestones {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Milestone[];
    }
    export interface PaginatedPipelineKnownHosts {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: PipelineKnownHost[];
      [k: string]: any;
    }
    export interface PaginatedPipelineScheduleExecutions {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: PipelineScheduleExecution[];
      [k: string]: any;
    }
    export interface PaginatedPipelineSchedules {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: PipelineSchedule[];
      [k: string]: any;
    }
    export interface PaginatedPipelineSteps {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: PipelineStep[];
      [k: string]: any;
    }
    export interface PipelineImage {
      email?: string;
      name?: string;
      password?: string;
      username?: string;
      [k: string]: any;
    }
    export interface PipelineCommand {
      command?: string;
      name?: string;
      [k: string]: any;
    }
    export interface PaginatedPipelineVariables {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: PipelineVariable[];
      [k: string]: any;
    }
    export interface PaginatedPipelines {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Pipeline[];
      [k: string]: any;
    }
    export interface PaginatedProjects {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Project[];
    }
    export interface PaginatedPullrequestComments {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: PullrequestComment[];
    }
    export interface PullrequestEndpoint {
      branch?: {
        default_merge_strategy?: string;
        merge_strategies?: ("merge_commit" | "squash" | "fast_forward")[];
        name?: string;
      };
      commit?: {
        hash?: string;
      };
      repository?: Repository;
    }
    export interface PaginatedPullrequests {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Pullrequest[];
    }
    export interface PaginatedRefs {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Ref[];
    }
    export interface PaginatedRepositories {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Repository[];
    }
    export interface PaginatedRepositoryPermissions {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: RepositoryPermission[];
    }
    export interface RepositoryPermission {
      permission?: "admin" | "write" | "read";
      repository?: Repository;
      type: string;
      user?: User;
      [k: string]: any;
    }
    export interface PaginatedSnippetComments {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: SnippetComment[];
    }
    export interface PaginatedSnippetCommit {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: SnippetCommit[];
    }
    export interface PaginatedSnippets {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Snippet[];
    }
    export interface PaginatedSshUserKeys {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: SshAccountKey[];
    }
    export interface PaginatedTags {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Tag[];
    }
    export interface PaginatedTeamPermissions {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: TeamPermission[];
    }
    export interface TeamPermission {
      permission?: "admin" | "collaborator";
      team?: Team;
      type: string;
      user?: User;
      [k: string]: any;
    }
    export interface PaginatedTeams {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Team[];
    }
    export interface PaginatedTreeentries {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Treeentry[];
    }
    export interface Treeentry {
      commit?: Commit;
      path?: string;
      type: string;
      [k: string]: any;
    }
    export interface PaginatedUsers {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: User[];
    }
    export interface PaginatedVersions {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: Version[];
    }
    export interface PaginatedWebhookSubscriptions {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      size?: number;
      values?: WebhookSubscription[];
    }
    export interface PullrequestMergeParameters {
      close_source_branch?: boolean;
      merge_strategy?: "merge_commit" | "squash" | "fast_forward";
      message?: string;
      type: string;
      [k: string]: any;
    }
    export interface SearchResultPage {
      next?: string;
      page?: number;
      pagelen?: number;
      previous?: string;
      query_substituted?: boolean;
      size?: number;
      values?: SearchCodeSearchResult[];
      [k: string]: any;
    }
    export interface SearchCodeSearchResult {
      content_match_count?: number;
      content_matches?: SearchContentMatch[];
      file?: CommitFile;
      path_matches?: SearchSegment[];
      type?: string;
      [k: string]: any;
    }
    export interface SearchContentMatch {
      lines?: SearchLine[];
      [k: string]: any;
    }
    export interface SearchLine {
      line?: number;
      segments?: SearchSegment[];
      [k: string]: any;
    }
    export interface SearchSegment {
      match?: boolean;
      text?: string;
      [k: string]: any;
    }
    export interface SubjectTypes {
      repository?: {
        events?: {
          href?: string;
          name?: string;
        };
      };
      team?: {
        events?: {
          href?: string;
          name?: string;
        };
      };
      user?: {
        events?: {
          href?: string;
          name?: string;
        };
      };
    }
  }

  namespace Params {
    export type Empty = {}

    export type BranchingModelGet =
      {
        "repo_slug": string;
        "username": string;
      };
    export type BranchingModelGetSettings =
      {
        "repo_slug": string;
        "username": string;
      };
    export type BranchingModelUpdateSettings =
      {
        "_body"?: Bitbucket.Schema.BranchingModelSettings;
        "repo_slug": string;
        "username": string;
      };
    export type BranchrestrictionsCreate =
      {
        "_body": Bitbucket.Schema.Branchrestriction;
        "repo_slug": string;
        "username": string;
      };
    export type BranchrestrictionsDelete =
      {
        "id": string;
        "repo_slug": string;
        "username": string;
      };
    export type BranchrestrictionsGet =
      {
        "id": string;
        "repo_slug": string;
        "username": string;
      };
    export type BranchrestrictionsList =
      {
        "kind"?: string;
        "page"?: string;
        "pagelen"?: number;
        "pattern"?: string;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type BranchrestrictionsUpdate =
      {
        "_body": Bitbucket.Schema.Branchrestriction;
        "id": string;
        "repo_slug": string;
        "username": string;
      };
    export type CommitsCreateApproval =
      {
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type CommitsCreateComment =
      {
        "_body": Bitbucket.Schema.CommitComment;
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type CommitsDeleteApproval =
      {
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type CommitsGet =
      {
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type CommitsGetComment =
      {
        "comment_id": number;
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type CommitsGetDiff =
      {
        "binary"?: boolean;
        "context"?: number;
        "ignore_whitespace"?: boolean;
        "path"?: string;
        "repo_slug": string;
        "spec": string;
        "username": string;
      };
    export type CommitsGetPatch =
      {
        "repo_slug": string;
        "spec": string;
        "username": string;
      };
    export type CommitsList =
      {
        "exclude"?: string;
        "include"?: string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type CommitsListAlt =
      {
        "exclude"?: string;
        "include"?: string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type CommitsListAt =
      {
        "exclude"?: string;
        "include"?: string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "revision": string;
        "sort"?: string;
        "username": string;
      };
    export type CommitsListAtAlt =
      {
        "exclude"?: string;
        "include"?: string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "revision": string;
        "sort"?: string;
        "username": string;
      };
    export type CommitsListComments =
      {
        "node": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type CommitstatusesCreateBuildStatus =
      {
        "_body"?: Bitbucket.Schema.Commitstatus;
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type CommitstatusesGetBuildStatus =
      {
        "key": string;
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type CommitstatusesList =
      {
        "node": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type CommitstatusesListPullRequestStatuses =
      {
        "page"?: string;
        "pagelen"?: number;
        "pull_request_id": number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type CommitstatusesUpdateBuildStatus =
      {
        "_body"?: Bitbucket.Schema.Commitstatus;
        "key": string;
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type DeployCreateKey =
      {
        "key": string;
        "label": string;
        "repo_slug": string;
        "username": string;
      };
    export type DeployDeleteKey =
      {
        "key_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type DeployGetKey =
      {
        "key_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type DeployListKeys =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type DeployUpdateKey =
      {
        "key_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type DeploymentsGet =
      {
        "deployment_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type DeploymentsGetEnvironment =
      {
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type DeploymentsList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type DeploymentsListEnvironments =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type DeploymentsUpdateEnvironment =
      {
        "_body": any;
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type DownloadsCreate =
      {
        "_body": FormData;
        "repo_slug": string;
        "username": string;
      };
    export type DownloadsDelete =
      {
        "filename": string;
        "repo_slug": string;
        "username": string;
      };
    export type DownloadsGet =
      {
        "filename": string;
        "repo_slug": string;
        "username": string;
      };
    export type DownloadsList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type HookEventsList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "subject_type": "workspace"|"user"|"repository"|"team";
      };
    export type IssueTrackerCreate =
      {
        "_body": Bitbucket.Schema.Issue;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerCreateAttachments =
      {
        "_body": FormData;
        "issue_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerCreateChange =
      {
        "_body": Bitbucket.Schema.IssueChange;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerCreateComment =
      {
        "_body": Bitbucket.Schema.IssueComment;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerCreateVote =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerCreateWatch =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerDelete =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerDeleteAttachment =
      {
        "issue_id": string;
        "path": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerDeleteComment =
      {
        "_body": Bitbucket.Schema.IssueComment;
        "comment_id": string;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerDeleteVote =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerDeleteWatch =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerGet =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerGetAttachment =
      {
        "issue_id": string;
        "path": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerGetChange =
      {
        "change_id": string;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerGetComment =
      {
        "comment_id": string;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerGetComponent =
      {
        "component_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerGetMilestone =
      {
        "milestone_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerGetVersion =
      {
        "repo_slug": string;
        "username": string;
        "version_id": number;
      };
    export type IssueTrackerGetVote =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerGetWatch =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type IssueTrackerListAttachments =
      {
        "issue_id": number;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type IssueTrackerListChanges =
      {
        "issue_id": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type IssueTrackerListComments =
      {
        "issue_id": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type IssueTrackerListComponents =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type IssueTrackerListMilestones =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type IssueTrackerListVersions =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type IssueTrackerUpdate =
      {
        "_body": Bitbucket.Schema.Issue;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type IssueTrackerUpdateComment =
      {
        "_body": Bitbucket.Schema.IssueComment;
        "comment_id": string;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesCreate =
      {
        "_body": Bitbucket.Schema.Pipeline;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesCreateDeploymentVariable =
      {
        "_body": Bitbucket.Schema.DeploymentVariable;
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesCreateKnownHost =
      {
        "_body": Bitbucket.Schema.PipelineKnownHost;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesCreateSchedule =
      {
        "_body": Bitbucket.Schema.PipelineSchedule;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesCreateVariable =
      {
        "_body": Bitbucket.Schema.PipelineVariable;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesCreateVariableForTeam =
      {
        "_body"?: Bitbucket.Schema.PipelineVariable;
        "username": string;
      };
    export type PipelinesCreateVariableForUser =
      {
        "_body"?: Bitbucket.Schema.PipelineVariable;
        "username": string;
      };
    export type PipelinesDeleteDeploymentVariable =
      {
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesDeleteKnownHost =
      {
        "known_host_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesDeleteSchedule =
      {
        "repo_slug": string;
        "schedule_uuid": string;
        "username": string;
      };
    export type PipelinesDeleteSshKeyPair =
      {
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesDeleteVariable =
      {
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesDeleteVariableForTeam =
      {
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesDeleteVariableForUser =
      {
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesGet =
      {
        "pipeline_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesGetConfig =
      {
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesGetKnownHost =
      {
        "known_host_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesGetSchedule =
      {
        "repo_slug": string;
        "schedule_uuid": string;
        "username": string;
      };
    export type PipelinesGetSshKeyPair =
      {
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesGetStep =
      {
        "pipeline_uuid": string;
        "repo_slug": string;
        "step_uuid": string;
        "username": string;
      };
    export type PipelinesGetStepLog =
      {
        "pipeline_uuid": string;
        "repo_slug": string;
        "step_uuid": string;
        "username": string;
      };
    export type PipelinesGetVariable =
      {
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesGetVariableForTeam =
      {
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesGetVariableForUser =
      {
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PipelinesListDeploymentVariables =
      {
        "environment_uuid": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PipelinesListKnownHosts =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PipelinesListScheduleExecutions =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PipelinesListSchedules =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PipelinesListSteps =
      {
        "page"?: string;
        "pagelen"?: number;
        "pipeline_uuid": string;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PipelinesListVariablesForRepo =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PipelinesListVariablesForTeam =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type PipelinesListVariablesForUser =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type PipelinesStop =
      {
        "pipeline_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesUpdateBuildNumber =
      {
        "_body": Bitbucket.Schema.PipelineBuildNumber;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesUpdateConfig =
      {
        "_body": Bitbucket.Schema.PipelinesConfig;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesUpdateDeploymentVariable =
      {
        "_body": Bitbucket.Schema.DeploymentVariable;
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesUpdateKnownHost =
      {
        "_body": Bitbucket.Schema.PipelineKnownHost;
        "known_host_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesUpdateSchedule =
      {
        "_body": Bitbucket.Schema.PipelineSchedule;
        "repo_slug": string;
        "schedule_uuid": string;
        "username": string;
      };
    export type PipelinesUpdateSshKeyPair =
      {
        "_body": Bitbucket.Schema.PipelineSshKeyPair;
        "repo_slug": string;
        "username": string;
      };
    export type PipelinesUpdateVariable =
      {
        "_body": Bitbucket.Schema.PipelineVariable;
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesUpdateVariableForTeam =
      {
        "_body": Bitbucket.Schema.PipelineVariable;
        "username": string;
        "variable_uuid": string;
      };
    export type PipelinesUpdateVariableForUser =
      {
        "_body": Bitbucket.Schema.PipelineVariable;
        "username": string;
        "variable_uuid": string;
      };
    export type ProjectsCreateForTeam =
      {
        "_body": Bitbucket.Schema.Project;
        "username": string;
      };
    export type ProjectsDeleteForTeam =
      {
        "project_key": string;
        "username": string;
      };
    export type ProjectsGetForTeam =
      {
        "project_key": string;
        "username": string;
      };
    export type ProjectsListForTeam =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type ProjectsUpdateForTeam =
      {
        "_body": Bitbucket.Schema.Project;
        "project_key": string;
        "username": string;
      };
    export type PullrequestsAddDefaultReviewer =
      {
        "repo_slug": string;
        "target_username": string;
        "username": string;
      };
    export type PullrequestsCreate =
      {
        "_body"?: Bitbucket.Schema.Pullrequest;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsCreateApproval =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsCreateComment =
      {
        "_body": Bitbucket.Schema.PullrequestComment;
        "pull_request_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsDecline =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsDeleteApproval =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsDeleteComment =
      {
        "comment_id": string;
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsDeleteDefaultReviewer =
      {
        "repo_slug": string;
        "target_username": string;
        "username": string;
      };
    export type PullrequestsGet =
      {
        "pull_request_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsGetComment =
      {
        "comment_id": string;
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsGetDefaultReviewer =
      {
        "repo_slug": string;
        "target_username": string;
        "username": string;
      };
    export type PullrequestsGetDiff =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsGetDiffStat =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsGetPatch =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "state"?: "MERGED"|"SUPERSEDED"|"OPEN"|"DECLINED";
        "username": string;
      };
    export type PullrequestsListActivities =
      {
        "page"?: string;
        "pagelen"?: number;
        "pull_request_id": number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PullrequestsListActivitiesForRepo =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PullrequestsListComments =
      {
        "page"?: string;
        "pagelen"?: number;
        "pull_request_id": number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PullrequestsListCommits =
      {
        "page"?: string;
        "pagelen"?: number;
        "pull_request_id": string;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PullrequestsListDefaultReviewers =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PullrequestsListForCommit =
      {
        "commit": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PullrequestsListStatuses =
      {
        "page"?: string;
        "pagelen"?: number;
        "pull_request_id": number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type PullrequestsMerge =
      {
        "_body"?: Bitbucket.Schema.PullrequestMergeParameters;
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsUpdate =
      {
        "_body"?: Bitbucket.Schema.Pullrequest;
        "pull_request_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type PullrequestsUpdateComment =
      {
        "_body": Bitbucket.Schema.PullrequestComment;
        "comment_id": string;
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RefsCreateBranch =
      {
        "_body": any;
        "repo_slug": string;
        "username": string;
      };
    export type RefsCreateTag =
      {
        "_body": Bitbucket.Schema.Tag;
        "repo_slug": string;
        "username": string;
      };
    export type RefsDeleteBranch =
      {
        "name": string;
        "repo_slug": string;
        "username": string;
      };
    export type RefsDeleteTag =
      {
        "name": string;
        "repo_slug": string;
        "username": string;
      };
    export type RefsGetBranch =
      {
        "name": string;
        "repo_slug": string;
        "username": string;
      };
    export type RefsGetTag =
      {
        "name": string;
        "repo_slug": string;
        "username": string;
      };
    export type RefsList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RefsListBranches =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RefsListTags =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesAddDefaultReviewer =
      {
        "repo_slug": string;
        "target_username": string;
        "username": string;
      };
    export type RepositoriesCreate =
      {
        "_body"?: Bitbucket.Schema.Repository;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateBranch =
      {
        "_body": any;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateBranchRestriction =
      {
        "_body": Bitbucket.Schema.Branchrestriction;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateCommitApproval =
      {
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateCommitBuildStatus =
      {
        "_body"?: Bitbucket.Schema.Commitstatus;
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateCommitComment =
      {
        "_body": Bitbucket.Schema.CommitComment;
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateDeployKey =
      {
        "key": string;
        "label": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateDeploymentVariable =
      {
        "_body": Bitbucket.Schema.DeploymentVariable;
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type RepositoriesCreateDownload =
      {
        "_body": FormData;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateEnvironment =
      {
        "_body": Bitbucket.Schema.DeploymentEnvironment;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateFork =
      {
        "_body"?: Bitbucket.Schema.Repository;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateIssue =
      {
        "_body": Bitbucket.Schema.Issue;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateIssueAttachments =
      {
        "_body": FormData;
        "issue_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateIssueChange =
      {
        "_body": Bitbucket.Schema.IssueChange;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateIssueComment =
      {
        "_body": Bitbucket.Schema.IssueComment;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateIssueExportJob =
      {
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateIssueImportJob =
      {
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateIssueVote =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateIssueWatch =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreatePipeline =
      {
        "_body": Bitbucket.Schema.Pipeline;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreatePipelineKnownHost =
      {
        "_body": Bitbucket.Schema.PipelineKnownHost;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreatePipelineSchedule =
      {
        "_body": Bitbucket.Schema.PipelineSchedule;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreatePipelineVariable =
      {
        "_body": Bitbucket.Schema.PipelineVariable;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreatePullRequest =
      {
        "_body"?: Bitbucket.Schema.Pullrequest;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreatePullRequestApproval =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreatePullRequestComment =
      {
        "_body": Bitbucket.Schema.PullrequestComment;
        "pull_request_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateSrcFileCommit =
      {
        "_body": FormData | Bitbucket.AnyObject;
        "author"?: string;
        "branch"?: string;
        "files"?: string;
        "message"?: string;
        "parents"?: string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateTag =
      {
        "_body": Bitbucket.Schema.Tag;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesCreateWebhook =
      {
        "_body": any;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeclinePullRequest =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDelete =
      {
        "redirect_to"?: string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteBranch =
      {
        "name": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteBranchRestriction =
      {
        "id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteCommitApproval =
      {
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteDefaultReviewer =
      {
        "repo_slug": string;
        "target_username": string;
        "username": string;
      };
    export type RepositoriesDeleteDeployKey =
      {
        "key_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteDeploymentVariable =
      {
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type RepositoriesDeleteDownload =
      {
        "filename": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteEnvironment =
      {
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteIssue =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteIssueAttachment =
      {
        "issue_id": string;
        "path": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteIssueComment =
      {
        "_body": Bitbucket.Schema.IssueComment;
        "comment_id": string;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteIssueVote =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteIssueWatch =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeletePipelineKnownHost =
      {
        "known_host_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeletePipelineSchedule =
      {
        "repo_slug": string;
        "schedule_uuid": string;
        "username": string;
      };
    export type RepositoriesDeletePipelineSshKeyPair =
      {
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeletePipelineVariable =
      {
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type RepositoriesDeletePullRequestApproval =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeletePullRequestComment =
      {
        "comment_id": string;
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteTag =
      {
        "name": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesDeleteWebhook =
      {
        "repo_slug": string;
        "uid": string;
        "username": string;
      };
    export type RepositoriesGet =
      {
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetBranch =
      {
        "name": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetBranchingModel =
      {
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetBranchingModelSettings =
      {
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetBranchRestriction =
      {
        "id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetCommit =
      {
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetCommitBuildStatus =
      {
        "key": string;
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetCommitComment =
      {
        "comment_id": number;
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetDefaultReviewer =
      {
        "repo_slug": string;
        "target_username": string;
        "username": string;
      };
    export type RepositoriesGetDeployKey =
      {
        "key_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetDeployment =
      {
        "deployment_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetDiff =
      {
        "binary"?: boolean;
        "context"?: number;
        "ignore_whitespace"?: boolean;
        "path"?: string;
        "repo_slug": string;
        "spec": string;
        "username": string;
      };
    export type RepositoriesGetDownload =
      {
        "filename": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetEnvironment =
      {
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetIssue =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetIssueAttachment =
      {
        "issue_id": string;
        "path": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetIssueChange =
      {
        "change_id": string;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetIssueComment =
      {
        "comment_id": string;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetIssueComponent =
      {
        "component_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetIssueExportJobStatus =
      {
        "repo_name": string;
        "repo_slug": string;
        "task_id": string;
        "username": string;
      };
    export type RepositoriesGetIssueImportJobStatus =
      {
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetIssueMilestone =
      {
        "milestone_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetIssueVersion =
      {
        "repo_slug": string;
        "username": string;
        "version_id": number;
      };
    export type RepositoriesGetIssueVote =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetIssueWatch =
      {
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetPatch =
      {
        "repo_slug": string;
        "spec": string;
        "username": string;
      };
    export type RepositoriesGetPipeline =
      {
        "pipeline_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetPipelineConfig =
      {
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetPipelineKnownHost =
      {
        "known_host_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetPipelineSchedule =
      {
        "repo_slug": string;
        "schedule_uuid": string;
        "username": string;
      };
    export type RepositoriesGetPipelineSshKeyPair =
      {
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetPipelineStep =
      {
        "pipeline_uuid": string;
        "repo_slug": string;
        "step_uuid": string;
        "username": string;
      };
    export type RepositoriesGetPipelineStepLog =
      {
        "pipeline_uuid": string;
        "repo_slug": string;
        "step_uuid": string;
        "username": string;
      };
    export type RepositoriesGetPipelineVariable =
      {
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type RepositoriesGetPullRequest =
      {
        "pull_request_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetPullRequestComment =
      {
        "comment_id": string;
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetPullRequestDiff =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetPullRequestDiffStat =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetPullRequestPatch =
      {
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetTag =
      {
        "name": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesGetWebhook =
      {
        "repo_slug": string;
        "uid": string;
        "username": string;
      };
    export type RepositoriesList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "role"?: "admin"|"contributor"|"member"|"owner";
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListBranches =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListBranchRestrictions =
      {
        "kind"?: string;
        "page"?: string;
        "pagelen"?: number;
        "pattern"?: string;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListCommitComments =
      {
        "node": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListCommits =
      {
        "exclude"?: string;
        "include"?: string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListCommitsAlt =
      {
        "exclude"?: string;
        "include"?: string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListCommitsAt =
      {
        "exclude"?: string;
        "include"?: string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "revision": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListCommitsAtAlt =
      {
        "exclude"?: string;
        "include"?: string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "revision": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListCommitStatuses =
      {
        "node": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListComponents =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListDefaultReviewers =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListDeployKeys =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListDeployments =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListDeploymentVariables =
      {
        "environment_uuid": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListDiffStats =
      {
        "ignore_whitespace"?: boolean;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "spec": string;
        "username": string;
      };
    export type RepositoriesListDownloads =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListEnvironments =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListFileHistory =
      {
        "fields"?: string;
        "node": string;
        "page"?: string;
        "pagelen"?: number;
        "path": string;
        "q"?: string;
        "renames"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListForks =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListIssueAttachments =
      {
        "issue_id": number;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListIssueChanges =
      {
        "issue_id": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListIssueComments =
      {
        "issue_id": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListIssues =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListMilestones =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPermissions =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
      };
    export type RepositoriesListPipelineKnownHosts =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPipelines =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPipelineScheduleExecutions =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPipelineSchedules =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPipelineSteps =
      {
        "page"?: string;
        "pagelen"?: number;
        "pipeline_uuid": string;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPipelineVariables =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPublic =
      {
        "after"?: string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "role"?: "admin"|"contributor"|"member"|"owner";
        "sort"?: string;
      };
    export type RepositoriesListPullRequestActivities =
      {
        "page"?: string;
        "pagelen"?: number;
        "pull_request_id": number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPullRequestActivitiesForRepo =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPullRequestComments =
      {
        "page"?: string;
        "pagelen"?: number;
        "pull_request_id": number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPullRequestCommits =
      {
        "page"?: string;
        "pagelen"?: number;
        "pull_request_id": string;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPullRequests =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "state"?: "MERGED"|"SUPERSEDED"|"OPEN"|"DECLINED";
        "username": string;
      };
    export type RepositoriesListPullrequestsForCommit =
      {
        "commit": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListPullRequestStatuses =
      {
        "page"?: string;
        "pagelen"?: number;
        "pull_request_id": number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListRefs =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListTags =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListVersions =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListWatchers =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesListWebhooks =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesMergePullRequest =
      {
        "_body"?: Bitbucket.Schema.PullrequestMergeParameters;
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesReadSrc =
      {
        "format"?: "meta"|"rendered";
        "max_depth"?: number;
        "node": string;
        "page"?: string;
        "pagelen"?: number;
        "path": string;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesReadSrcRoot =
      {
        "format"?: "meta";
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type RepositoriesStopPipeline =
      {
        "pipeline_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdate =
      {
        "_body"?: Bitbucket.Schema.Repository;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdateBranchingModelSettings =
      {
        "_body"?: Bitbucket.Schema.BranchingModelSettings;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdateBranchRestriction =
      {
        "_body": Bitbucket.Schema.Branchrestriction;
        "id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdateCommitBuildStatus =
      {
        "_body"?: Bitbucket.Schema.Commitstatus;
        "key": string;
        "node": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdateDeployKey =
      {
        "key_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdateDeploymentVariable =
      {
        "_body": Bitbucket.Schema.DeploymentVariable;
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type RepositoriesUpdateEnvironment =
      {
        "_body": any;
        "environment_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdateIssue =
      {
        "_body": Bitbucket.Schema.Issue;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdateIssueComment =
      {
        "_body": Bitbucket.Schema.IssueComment;
        "comment_id": string;
        "issue_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdatePipelineBuildNumber =
      {
        "_body": Bitbucket.Schema.PipelineBuildNumber;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdatePipelineConfig =
      {
        "_body": Bitbucket.Schema.PipelinesConfig;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdatePipelineKnownHost =
      {
        "_body": Bitbucket.Schema.PipelineKnownHost;
        "known_host_uuid": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdatePipelineSchedule =
      {
        "_body": Bitbucket.Schema.PipelineSchedule;
        "repo_slug": string;
        "schedule_uuid": string;
        "username": string;
      };
    export type RepositoriesUpdatePipelineSshKeyPair =
      {
        "_body": Bitbucket.Schema.PipelineSshKeyPair;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdatePipelineVariable =
      {
        "_body": Bitbucket.Schema.PipelineVariable;
        "repo_slug": string;
        "username": string;
        "variable_uuid": string;
      };
    export type RepositoriesUpdatePullRequest =
      {
        "_body"?: Bitbucket.Schema.Pullrequest;
        "pull_request_id": number;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdatePullRequestComment =
      {
        "_body": Bitbucket.Schema.PullrequestComment;
        "comment_id": string;
        "pull_request_id": string;
        "repo_slug": string;
        "username": string;
      };
    export type RepositoriesUpdateWebhook =
      {
        "repo_slug": string;
        "uid": string;
        "username": string;
      };
    export type SearchCodeOfTeam =
      {
        "page"?: number;
        "pagelen"?: number;
        "search_query": string;
        "username": string;
      };
    export type SearchCodeOfUser =
      {
        "page"?: number;
        "pagelen"?: number;
        "search_query": string;
        "username": string;
      };
    export type SnippetGetRawFiles =
      {
        "encoded_id": string;
        "path": string;
        "username": string;
      };
    export type SnippetsCheckWatch =
      {
        "encoded_id": string;
        "username": string;
      };
    export type SnippetsCreate =
      {
        "_body": Bitbucket.Schema.Snippet;
      };
    export type SnippetsCreateComment =
      {
        "_body": Bitbucket.Schema.Snippet;
        "encoded_id": string;
        "username": string;
      };
    export type SnippetsCreateForUser =
      {
        "_body": Bitbucket.Schema.Snippet;
        "username": string;
      };
    export type SnippetsDelete =
      {
        "encoded_id": string;
        "username": string;
      };
    export type SnippetsDeleteAt =
      {
        "encoded_id": string;
        "node_id": string;
        "username": string;
      };
    export type SnippetsDeleteComment =
      {
        "comment_id": string;
        "encoded_id": string;
        "username": string;
      };
    export type SnippetsGet =
      {
        "encoded_id": string;
        "username": string;
      };
    export type SnippetsGetAt =
      {
        "encoded_id": string;
        "node_id": string;
        "username": string;
      };
    export type SnippetsGetComment =
      {
        "comment_id": string;
        "encoded_id": string;
        "username": string;
      };
    export type SnippetsGetCommit =
      {
        "encoded_id": string;
        "revision": string;
        "username": string;
      };
    export type SnippetsGetDiff =
      {
        "encoded_id": string;
        "path"?: string;
        "revision": string;
        "username": string;
      };
    export type SnippetsGetFile =
      {
        "encoded_id": string;
        "node_id": string;
        "path": string;
        "username": string;
      };
    export type SnippetsGetPatch =
      {
        "encoded_id": string;
        "revision": string;
        "username": string;
      };
    export type SnippetsGetRawFiles =
      {
        "encoded_id": string;
        "path": string;
        "username": string;
      };
    export type SnippetsList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "role"?: "owner"|"contributor"|"member";
        "sort"?: string;
      };
    export type SnippetsListComments =
      {
        "encoded_id": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type SnippetsListCommits =
      {
        "encoded_id": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type SnippetsListForUser =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "role"?: "owner"|"contributor"|"member";
        "sort"?: string;
        "username": string;
      };
    export type SnippetsListWatchers =
      {
        "encoded_id": string;
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type SnippetsStartWatch =
      {
        "encoded_id": string;
        "username": string;
      };
    export type SnippetsStopWatch =
      {
        "encoded_id": string;
        "username": string;
      };
    export type SnippetsUpdate =
      {
        "encoded_id": string;
        "username": string;
      };
    export type SnippetsUpdateAt =
      {
        "encoded_id": string;
        "node_id": string;
        "username": string;
      };
    export type SnippetsUpdateComment =
      {
        "comment_id": string;
        "encoded_id": string;
        "username": string;
      };
    export type SourceCreateFileCommit =
      {
        "_body": FormData | Bitbucket.AnyObject;
        "author"?: string;
        "branch"?: string;
        "files"?: string;
        "message"?: string;
        "parents"?: string;
        "repo_slug": string;
        "username": string;
      };
    export type SourceListHistory =
      {
        "fields"?: string;
        "node": string;
        "page"?: string;
        "pagelen"?: number;
        "path": string;
        "q"?: string;
        "renames"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type SourceRead =
      {
        "format"?: "meta"|"rendered";
        "max_depth"?: number;
        "node": string;
        "page"?: string;
        "pagelen"?: number;
        "path": string;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type SourceReadRoot =
      {
        "format"?: "meta";
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type SshCreateKey =
      {
        "_body"?: Bitbucket.Schema.SshAccountKey;
        "username": string;
      };
    export type SshListKeys =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsCreatePipelineVariable =
      {
        "_body"?: Bitbucket.Schema.PipelineVariable;
        "username": string;
      };
    export type TeamsCreateProject =
      {
        "_body": Bitbucket.Schema.Project;
        "username": string;
      };
    export type TeamsCreateWebhook =
      {
        "username": string;
      };
    export type TeamsDeletePipelineVariable =
      {
        "username": string;
        "variable_uuid": string;
      };
    export type TeamsDeleteProject =
      {
        "project_key": string;
        "username": string;
      };
    export type TeamsDeleteWebhook =
      {
        "uid": string;
        "username": string;
      };
    export type TeamsGet =
      {
        "username": string;
      };
    export type TeamsGetAllMembers =
      {
        "username": string;
      };
    export type TeamsGetMembers =
      {
        "username": string;
      };
    export type TeamsGetPipelineVariable =
      {
        "username": string;
        "variable_uuid": string;
      };
    export type TeamsGetProject =
      {
        "project_key": string;
        "username": string;
      };
    export type TeamsGetWebhook =
      {
        "uid": string;
        "username": string;
      };
    export type TeamsList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "role"?: "admin"|"contributor"|"member";
        "sort"?: string;
      };
    export type TeamsListFollowers =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsListFollowing =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsListPermissions =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsListPermissionsForRepo =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsListPermissionsForRepos =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsListPipelineVariables =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsListProjects =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsListRepositories =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsListRepositoriesForUser =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsListWebhooks =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type TeamsSearchCode =
      {
        "page"?: number;
        "pagelen"?: number;
        "search_query": string;
        "username": string;
      };
    export type TeamsUpdatePipelineVariable =
      {
        "_body": Bitbucket.Schema.PipelineVariable;
        "username": string;
        "variable_uuid": string;
      };
    export type TeamsUpdateProject =
      {
        "_body": Bitbucket.Schema.Project;
        "project_key": string;
        "username": string;
      };
    export type TeamsUpdateWebhook =
      {
        "uid": string;
        "username": string;
      };
    export type UserGetEmail =
      {
        "email": string;
      };
    export type UserListEmails =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
      };
    export type UserListPermissionsForRepos =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
      };
    export type UserListPermissionsForTeams =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
      };
    export type UsersCreatePipelineVariable =
      {
        "_body"?: Bitbucket.Schema.PipelineVariable;
        "username": string;
      };
    export type UsersCreateSshKey =
      {
        "_body"?: Bitbucket.Schema.SshAccountKey;
        "username": string;
      };
    export type UsersCreateWebhook =
      {
        "username": string;
      };
    export type UsersDeletePipelineVariable =
      {
        "username": string;
        "variable_uuid": string;
      };
    export type UsersDeleteWebhook =
      {
        "uid": string;
        "username": string;
      };
    export type UsersGet =
      {
        "username": string;
      };
    export type UsersGetEmailForAuthedUser =
      {
        "email": string;
      };
    export type UsersGetPipelineVariable =
      {
        "username": string;
        "variable_uuid": string;
      };
    export type UsersGetTeamMembers =
      {
        "username": string;
      };
    export type UsersGetWebhook =
      {
        "uid": string;
        "username": string;
      };
    export type UsersListEmailsForAuthedUser =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
      };
    export type UsersListFollowers =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type UsersListFollowing =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type UsersListPipelineVariables =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type UsersListRepositories =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type UsersListRepositoriesForTeam =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type UsersListSshKeys =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type UsersListWebhooks =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type UsersSearchCode =
      {
        "page"?: number;
        "pagelen"?: number;
        "search_query": string;
        "username": string;
      };
    export type UsersUpdatePipelineVariable =
      {
        "_body": Bitbucket.Schema.PipelineVariable;
        "username": string;
        "variable_uuid": string;
      };
    export type UsersUpdateWebhook =
      {
        "uid": string;
        "username": string;
      };
    export type WebhooksCreate =
      {
        "_body": any;
        "repo_slug": string;
        "username": string;
      };
    export type WebhooksCreateForTeam =
      {
        "username": string;
      };
    export type WebhooksCreateForUser =
      {
        "username": string;
      };
    export type WebhooksDelete =
      {
        "repo_slug": string;
        "uid": string;
        "username": string;
      };
    export type WebhooksDeleteForTeam =
      {
        "uid": string;
        "username": string;
      };
    export type WebhooksDeleteForUser =
      {
        "uid": string;
        "username": string;
      };
    export type WebhooksGet =
      {
        "repo_slug": string;
        "uid": string;
        "username": string;
      };
    export type WebhooksGetForTeam =
      {
        "uid": string;
        "username": string;
      };
    export type WebhooksGetForUser =
      {
        "uid": string;
        "username": string;
      };
    export type WebhooksList =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "subject_type": "workspace"|"user"|"repository"|"team";
      };
    export type WebhooksListForRepo =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "repo_slug": string;
        "sort"?: string;
        "username": string;
      };
    export type WebhooksListForTeam =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type WebhooksListForUser =
      {
        "page"?: string;
        "pagelen"?: number;
        "q"?: string;
        "sort"?: string;
        "username": string;
      };
    export type WebhooksUpdate =
      {
        "repo_slug": string;
        "uid": string;
        "username": string;
      };
    export type WebhooksUpdateForTeam =
      {
        "uid": string;
        "username": string;
      };
    export type WebhooksUpdateForUser =
      {
        "uid": string;
        "username": string;
      };
  }
}

declare class Bitbucket {
  constructor(options?: Bitbucket.Options);

  authenticate(auth: Bitbucket.Auth): void;

  hasNextPage(data: Bitbucket.PaginatedData): boolean;
  getNextPage<T>(data: T, callback?: Bitbucket.Callback<Bitbucket.Response<T>>): Promise<Bitbucket.Response<T>>;

  hasPreviousPage(data: Bitbucket.PaginatedData): boolean;
  getPreviousPage<T>(data: T, callback?: Bitbucket.Callback<Bitbucket.Response<T>>): Promise<Bitbucket.Response<T>>;

  branching_model: {
    get(params: Bitbucket.Params.BranchingModelGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.BranchingModel>>): Promise<Bitbucket.Response<Bitbucket.Schema.BranchingModel>>;
    getSettings(params: Bitbucket.Params.BranchingModelGetSettings, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.BranchingModelSettings>>): Promise<Bitbucket.Response<Bitbucket.Schema.BranchingModelSettings>>;
    updateSettings(params: Bitbucket.Params.BranchingModelUpdateSettings, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.BranchingModelSettings>>): Promise<Bitbucket.Response<Bitbucket.Schema.BranchingModelSettings>>;
  };
  branchrestrictions: {
    create(params: Bitbucket.Params.BranchrestrictionsCreate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>): Promise<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>;
    delete(params: Bitbucket.Params.BranchrestrictionsDelete, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    get(params: Bitbucket.Params.BranchrestrictionsGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>): Promise<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>;
    list(params: Bitbucket.Params.BranchrestrictionsList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedBranchrestrictions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedBranchrestrictions>>;
    update(params: Bitbucket.Params.BranchrestrictionsUpdate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>): Promise<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>;
  };
  commits: {
    createApproval(params: Bitbucket.Params.CommitsCreateApproval, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Participant>>): Promise<Bitbucket.Response<Bitbucket.Schema.Participant>>;
    createComment(params: Bitbucket.Params.CommitsCreateComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteApproval(params: Bitbucket.Params.CommitsDeleteApproval, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    get(params: Bitbucket.Params.CommitsGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Commit>>): Promise<Bitbucket.Response<Bitbucket.Schema.Commit>>;
    getComment(params: Bitbucket.Params.CommitsGetComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.CommitComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.CommitComment>>;
    getDiff(params: Bitbucket.Params.CommitsGetDiff, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getPatch(params: Bitbucket.Params.CommitsGetPatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    list(params: Bitbucket.Params.CommitsList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listAlt(params: Bitbucket.Params.CommitsListAlt, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listAt(params: Bitbucket.Params.CommitsListAt, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listAtAlt(params: Bitbucket.Params.CommitsListAtAlt, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listComments(params: Bitbucket.Params.CommitsListComments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitComments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitComments>>;
  };
  commitstatuses: {
    createBuildStatus(params: Bitbucket.Params.CommitstatusesCreateBuildStatus, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>): Promise<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>;
    getBuildStatus(params: Bitbucket.Params.CommitstatusesGetBuildStatus, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>): Promise<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>;
    list(params: Bitbucket.Params.CommitstatusesList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitstatuses>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitstatuses>>;
    listPullRequestStatuses(params: Bitbucket.Params.CommitstatusesListPullRequestStatuses, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitstatuses>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitstatuses>>;
    updateBuildStatus(params: Bitbucket.Params.CommitstatusesUpdateBuildStatus, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>): Promise<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>;
  };
  deploy: {
    createKey(params: Bitbucket.Params.DeployCreateKey, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeployKey>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeployKey>>;
    deleteKey(params: Bitbucket.Params.DeployDeleteKey, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getKey(params: Bitbucket.Params.DeployGetKey, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeployKey>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeployKey>>;
    listKeys(params: Bitbucket.Params.DeployListKeys, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedDeployKeys>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedDeployKeys>>;
    updateKey(params: Bitbucket.Params.DeployUpdateKey, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeployKey>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeployKey>>;
  };
  deployments: {
    get(params: Bitbucket.Params.DeploymentsGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Deployment>>): Promise<Bitbucket.Response<Bitbucket.Schema.Deployment>>;
    getEnvironment(params: Bitbucket.Params.DeploymentsGetEnvironment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeploymentEnvironment>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeploymentEnvironment>>;
    list(params: Bitbucket.Params.DeploymentsList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedDeployments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedDeployments>>;
    listEnvironments(params: Bitbucket.Params.DeploymentsListEnvironments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedEnvironments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedEnvironments>>;
    updateEnvironment(params: Bitbucket.Params.DeploymentsUpdateEnvironment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
  };
  downloads: {
    create(params: Bitbucket.Params.DownloadsCreate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    delete(params: Bitbucket.Params.DownloadsDelete, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    get(params: Bitbucket.Params.DownloadsGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    list(params: Bitbucket.Params.DownloadsList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
  };
  hook_events: {
    getAllSubjectTypes(params: Bitbucket.Params.Empty, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.SubjectTypes>>): Promise<Bitbucket.Response<Bitbucket.Schema.SubjectTypes>>;
    list(params: Bitbucket.Params.HookEventsList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedHookEvents>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedHookEvents>>;
  };
  issue_tracker: {
    create(params: Bitbucket.Params.IssueTrackerCreate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Issue>>): Promise<Bitbucket.Response<Bitbucket.Schema.Issue>>;
    createAttachments(params: Bitbucket.Params.IssueTrackerCreateAttachments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    createChange(params: Bitbucket.Params.IssueTrackerCreateChange, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueChange>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueChange>>;
    createComment(params: Bitbucket.Params.IssueTrackerCreateComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    createVote(params: Bitbucket.Params.IssueTrackerCreateVote, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Error>>): Promise<Bitbucket.Response<Bitbucket.Schema.Error>>;
    createWatch(params: Bitbucket.Params.IssueTrackerCreateWatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Error>>): Promise<Bitbucket.Response<Bitbucket.Schema.Error>>;
    delete(params: Bitbucket.Params.IssueTrackerDelete, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Issue>>): Promise<Bitbucket.Response<Bitbucket.Schema.Issue>>;
    deleteAttachment(params: Bitbucket.Params.IssueTrackerDeleteAttachment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteComment(params: Bitbucket.Params.IssueTrackerDeleteComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteVote(params: Bitbucket.Params.IssueTrackerDeleteVote, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteWatch(params: Bitbucket.Params.IssueTrackerDeleteWatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Error>>): Promise<Bitbucket.Response<Bitbucket.Schema.Error>>;
    get(params: Bitbucket.Params.IssueTrackerGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Issue>>): Promise<Bitbucket.Response<Bitbucket.Schema.Issue>>;
    getAttachment(params: Bitbucket.Params.IssueTrackerGetAttachment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getChange(params: Bitbucket.Params.IssueTrackerGetChange, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueChange>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueChange>>;
    getComment(params: Bitbucket.Params.IssueTrackerGetComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueComment>>;
    getComponent(params: Bitbucket.Params.IssueTrackerGetComponent, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Component>>): Promise<Bitbucket.Response<Bitbucket.Schema.Component>>;
    getMilestone(params: Bitbucket.Params.IssueTrackerGetMilestone, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Milestone>>): Promise<Bitbucket.Response<Bitbucket.Schema.Milestone>>;
    getVersion(params: Bitbucket.Params.IssueTrackerGetVersion, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Version>>): Promise<Bitbucket.Response<Bitbucket.Schema.Version>>;
    getVote(params: Bitbucket.Params.IssueTrackerGetVote, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Error>>): Promise<Bitbucket.Response<Bitbucket.Schema.Error>>;
    getWatch(params: Bitbucket.Params.IssueTrackerGetWatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Error>>): Promise<Bitbucket.Response<Bitbucket.Schema.Error>>;
    list(params: Bitbucket.Params.IssueTrackerList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedIssues>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedIssues>>;
    listAttachments(params: Bitbucket.Params.IssueTrackerListAttachments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedIssueAttachments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedIssueAttachments>>;
    listChanges(params: Bitbucket.Params.IssueTrackerListChanges, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedLogEntries>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedLogEntries>>;
    listComments(params: Bitbucket.Params.IssueTrackerListComments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedIssueComments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedIssueComments>>;
    listComponents(params: Bitbucket.Params.IssueTrackerListComponents, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedComponents>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedComponents>>;
    listMilestones(params: Bitbucket.Params.IssueTrackerListMilestones, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedMilestones>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedMilestones>>;
    listVersions(params: Bitbucket.Params.IssueTrackerListVersions, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedVersions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedVersions>>;
    update(params: Bitbucket.Params.IssueTrackerUpdate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Issue>>): Promise<Bitbucket.Response<Bitbucket.Schema.Issue>>;
    updateComment(params: Bitbucket.Params.IssueTrackerUpdateComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueComment>>;
  };
  pipelines: {
    create(params: Bitbucket.Params.PipelinesCreate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pipeline>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pipeline>>;
    createDeploymentVariable(params: Bitbucket.Params.PipelinesCreateDeploymentVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeploymentVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeploymentVariable>>;
    createKnownHost(params: Bitbucket.Params.PipelinesCreateKnownHost, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>;
    createSchedule(params: Bitbucket.Params.PipelinesCreateSchedule, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>;
    createVariable(params: Bitbucket.Params.PipelinesCreateVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    createVariableForTeam(params: Bitbucket.Params.PipelinesCreateVariableForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    createVariableForUser(params: Bitbucket.Params.PipelinesCreateVariableForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    deleteDeploymentVariable(params: Bitbucket.Params.PipelinesDeleteDeploymentVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteKnownHost(params: Bitbucket.Params.PipelinesDeleteKnownHost, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteSchedule(params: Bitbucket.Params.PipelinesDeleteSchedule, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteSshKeyPair(params: Bitbucket.Params.PipelinesDeleteSshKeyPair, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteVariable(params: Bitbucket.Params.PipelinesDeleteVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteVariableForTeam(params: Bitbucket.Params.PipelinesDeleteVariableForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteVariableForUser(params: Bitbucket.Params.PipelinesDeleteVariableForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    get(params: Bitbucket.Params.PipelinesGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pipeline>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pipeline>>;
    getConfig(params: Bitbucket.Params.PipelinesGetConfig, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelinesConfig>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelinesConfig>>;
    getKnownHost(params: Bitbucket.Params.PipelinesGetKnownHost, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>;
    getSchedule(params: Bitbucket.Params.PipelinesGetSchedule, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>;
    getSshKeyPair(params: Bitbucket.Params.PipelinesGetSshKeyPair, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineSshKeyPair>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineSshKeyPair>>;
    getStep(params: Bitbucket.Params.PipelinesGetStep, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineStep>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineStep>>;
    getStepLog(params: Bitbucket.Params.PipelinesGetStepLog, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getVariable(params: Bitbucket.Params.PipelinesGetVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    getVariableForTeam(params: Bitbucket.Params.PipelinesGetVariableForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    getVariableForUser(params: Bitbucket.Params.PipelinesGetVariableForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    list(params: Bitbucket.Params.PipelinesList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelines>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelines>>;
    listDeploymentVariables(params: Bitbucket.Params.PipelinesListDeploymentVariables, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedDeploymentVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedDeploymentVariable>>;
    listKnownHosts(params: Bitbucket.Params.PipelinesListKnownHosts, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineKnownHosts>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineKnownHosts>>;
    listScheduleExecutions(params: Bitbucket.Params.PipelinesListScheduleExecutions, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineScheduleExecutions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineScheduleExecutions>>;
    listSchedules(params: Bitbucket.Params.PipelinesListSchedules, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineSchedules>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineSchedules>>;
    listSteps(params: Bitbucket.Params.PipelinesListSteps, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineSteps>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineSteps>>;
    listVariablesForRepo(params: Bitbucket.Params.PipelinesListVariablesForRepo, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>;
    listVariablesForTeam(params: Bitbucket.Params.PipelinesListVariablesForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>;
    listVariablesForUser(params: Bitbucket.Params.PipelinesListVariablesForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>;
    stop(params: Bitbucket.Params.PipelinesStop, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    updateBuildNumber(params: Bitbucket.Params.PipelinesUpdateBuildNumber, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineBuildNumber>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineBuildNumber>>;
    updateConfig(params: Bitbucket.Params.PipelinesUpdateConfig, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelinesConfig>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelinesConfig>>;
    updateDeploymentVariable(params: Bitbucket.Params.PipelinesUpdateDeploymentVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeploymentVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeploymentVariable>>;
    updateKnownHost(params: Bitbucket.Params.PipelinesUpdateKnownHost, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>;
    updateSchedule(params: Bitbucket.Params.PipelinesUpdateSchedule, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>;
    updateSshKeyPair(params: Bitbucket.Params.PipelinesUpdateSshKeyPair, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineSshKeyPair>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineSshKeyPair>>;
    updateVariable(params: Bitbucket.Params.PipelinesUpdateVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    updateVariableForTeam(params: Bitbucket.Params.PipelinesUpdateVariableForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    updateVariableForUser(params: Bitbucket.Params.PipelinesUpdateVariableForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
  };
  projects: {
    createForTeam(params: Bitbucket.Params.ProjectsCreateForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Project>>): Promise<Bitbucket.Response<Bitbucket.Schema.Project>>;
    deleteForTeam(params: Bitbucket.Params.ProjectsDeleteForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getForTeam(params: Bitbucket.Params.ProjectsGetForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Project>>): Promise<Bitbucket.Response<Bitbucket.Schema.Project>>;
    listForTeam(params: Bitbucket.Params.ProjectsListForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedProjects>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedProjects>>;
    updateForTeam(params: Bitbucket.Params.ProjectsUpdateForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Project>>): Promise<Bitbucket.Response<Bitbucket.Schema.Project>>;
  };
  pullrequests: {
    addDefaultReviewer(params: Bitbucket.Params.PullrequestsAddDefaultReviewer, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    create(params: Bitbucket.Params.PullrequestsCreate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>;
    createApproval(params: Bitbucket.Params.PullrequestsCreateApproval, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Participant>>): Promise<Bitbucket.Response<Bitbucket.Schema.Participant>>;
    createComment(params: Bitbucket.Params.PullrequestsCreateComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>;
    decline(params: Bitbucket.Params.PullrequestsDecline, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>;
    deleteApproval(params: Bitbucket.Params.PullrequestsDeleteApproval, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteComment(params: Bitbucket.Params.PullrequestsDeleteComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteDefaultReviewer(params: Bitbucket.Params.PullrequestsDeleteDefaultReviewer, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    get(params: Bitbucket.Params.PullrequestsGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>;
    getComment(params: Bitbucket.Params.PullrequestsGetComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>;
    getDefaultReviewer(params: Bitbucket.Params.PullrequestsGetDefaultReviewer, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getDiff(params: Bitbucket.Params.PullrequestsGetDiff, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getDiffStat(params: Bitbucket.Params.PullrequestsGetDiffStat, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getPatch(params: Bitbucket.Params.PullrequestsGetPatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    list(params: Bitbucket.Params.PullrequestsList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequests>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequests>>;
    listActivities(params: Bitbucket.Params.PullrequestsListActivities, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listActivitiesForRepo(params: Bitbucket.Params.PullrequestsListActivitiesForRepo, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listComments(params: Bitbucket.Params.PullrequestsListComments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequestComments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequestComments>>;
    listCommits(params: Bitbucket.Params.PullrequestsListCommits, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listDefaultReviewers(params: Bitbucket.Params.PullrequestsListDefaultReviewers, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listForCommit(params: Bitbucket.Params.PullrequestsListForCommit, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequests>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequests>>;
    listStatuses(params: Bitbucket.Params.PullrequestsListStatuses, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitstatuses>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitstatuses>>;
    merge(params: Bitbucket.Params.PullrequestsMerge, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>;
    update(params: Bitbucket.Params.PullrequestsUpdate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>;
    updateComment(params: Bitbucket.Params.PullrequestsUpdateComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>;
  };
  refs: {
    createBranch(params: Bitbucket.Params.RefsCreateBranch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Branch>>): Promise<Bitbucket.Response<Bitbucket.Schema.Branch>>;
    createTag(params: Bitbucket.Params.RefsCreateTag, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Tag>>): Promise<Bitbucket.Response<Bitbucket.Schema.Tag>>;
    deleteBranch(params: Bitbucket.Params.RefsDeleteBranch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteTag(params: Bitbucket.Params.RefsDeleteTag, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getBranch(params: Bitbucket.Params.RefsGetBranch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Branch>>): Promise<Bitbucket.Response<Bitbucket.Schema.Branch>>;
    getTag(params: Bitbucket.Params.RefsGetTag, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Tag>>): Promise<Bitbucket.Response<Bitbucket.Schema.Tag>>;
    list(params: Bitbucket.Params.RefsList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedRefs>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedRefs>>;
    listBranches(params: Bitbucket.Params.RefsListBranches, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedBranches>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedBranches>>;
    listTags(params: Bitbucket.Params.RefsListTags, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedTags>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedTags>>;
  };
  repositories: {
    addDefaultReviewer(params: Bitbucket.Params.RepositoriesAddDefaultReviewer, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    create(params: Bitbucket.Params.RepositoriesCreate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Repository>>): Promise<Bitbucket.Response<Bitbucket.Schema.Repository>>;
    createBranch(params: Bitbucket.Params.RepositoriesCreateBranch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Branch>>): Promise<Bitbucket.Response<Bitbucket.Schema.Branch>>;
    createBranchRestriction(params: Bitbucket.Params.RepositoriesCreateBranchRestriction, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>): Promise<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>;
    createCommitApproval(params: Bitbucket.Params.RepositoriesCreateCommitApproval, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Participant>>): Promise<Bitbucket.Response<Bitbucket.Schema.Participant>>;
    createCommitBuildStatus(params: Bitbucket.Params.RepositoriesCreateCommitBuildStatus, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>): Promise<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>;
    createCommitComment(params: Bitbucket.Params.RepositoriesCreateCommitComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    createDeployKey(params: Bitbucket.Params.RepositoriesCreateDeployKey, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeployKey>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeployKey>>;
    createDeploymentVariable(params: Bitbucket.Params.RepositoriesCreateDeploymentVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeploymentVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeploymentVariable>>;
    createDownload(params: Bitbucket.Params.RepositoriesCreateDownload, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    createEnvironment(params: Bitbucket.Params.RepositoriesCreateEnvironment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeploymentEnvironment>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeploymentEnvironment>>;
    createFork(params: Bitbucket.Params.RepositoriesCreateFork, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Repository>>): Promise<Bitbucket.Response<Bitbucket.Schema.Repository>>;
    createIssue(params: Bitbucket.Params.RepositoriesCreateIssue, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Issue>>): Promise<Bitbucket.Response<Bitbucket.Schema.Issue>>;
    createIssueAttachments(params: Bitbucket.Params.RepositoriesCreateIssueAttachments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    createIssueChange(params: Bitbucket.Params.RepositoriesCreateIssueChange, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueChange>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueChange>>;
    createIssueComment(params: Bitbucket.Params.RepositoriesCreateIssueComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    createIssueExportJob(params: Bitbucket.Params.RepositoriesCreateIssueExportJob, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    createIssueImportJob(params: Bitbucket.Params.RepositoriesCreateIssueImportJob, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueJobStatus>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueJobStatus>>;
    createIssueVote(params: Bitbucket.Params.RepositoriesCreateIssueVote, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Error>>): Promise<Bitbucket.Response<Bitbucket.Schema.Error>>;
    createIssueWatch(params: Bitbucket.Params.RepositoriesCreateIssueWatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Error>>): Promise<Bitbucket.Response<Bitbucket.Schema.Error>>;
    createPipeline(params: Bitbucket.Params.RepositoriesCreatePipeline, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pipeline>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pipeline>>;
    createPipelineKnownHost(params: Bitbucket.Params.RepositoriesCreatePipelineKnownHost, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>;
    createPipelineSchedule(params: Bitbucket.Params.RepositoriesCreatePipelineSchedule, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>;
    createPipelineVariable(params: Bitbucket.Params.RepositoriesCreatePipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    createPullRequest(params: Bitbucket.Params.RepositoriesCreatePullRequest, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>;
    createPullRequestApproval(params: Bitbucket.Params.RepositoriesCreatePullRequestApproval, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Participant>>): Promise<Bitbucket.Response<Bitbucket.Schema.Participant>>;
    createPullRequestComment(params: Bitbucket.Params.RepositoriesCreatePullRequestComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>;
    createSrcFileCommit(params: Bitbucket.Params.RepositoriesCreateSrcFileCommit, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    createTag(params: Bitbucket.Params.RepositoriesCreateTag, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Tag>>): Promise<Bitbucket.Response<Bitbucket.Schema.Tag>>;
    createWebhook(params: Bitbucket.Params.RepositoriesCreateWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    declinePullRequest(params: Bitbucket.Params.RepositoriesDeclinePullRequest, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>;
    delete(params: Bitbucket.Params.RepositoriesDelete, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteBranch(params: Bitbucket.Params.RepositoriesDeleteBranch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteBranchRestriction(params: Bitbucket.Params.RepositoriesDeleteBranchRestriction, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteCommitApproval(params: Bitbucket.Params.RepositoriesDeleteCommitApproval, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteDefaultReviewer(params: Bitbucket.Params.RepositoriesDeleteDefaultReviewer, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteDeployKey(params: Bitbucket.Params.RepositoriesDeleteDeployKey, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteDeploymentVariable(params: Bitbucket.Params.RepositoriesDeleteDeploymentVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteDownload(params: Bitbucket.Params.RepositoriesDeleteDownload, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteEnvironment(params: Bitbucket.Params.RepositoriesDeleteEnvironment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteIssue(params: Bitbucket.Params.RepositoriesDeleteIssue, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Issue>>): Promise<Bitbucket.Response<Bitbucket.Schema.Issue>>;
    deleteIssueAttachment(params: Bitbucket.Params.RepositoriesDeleteIssueAttachment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteIssueComment(params: Bitbucket.Params.RepositoriesDeleteIssueComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteIssueVote(params: Bitbucket.Params.RepositoriesDeleteIssueVote, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteIssueWatch(params: Bitbucket.Params.RepositoriesDeleteIssueWatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Error>>): Promise<Bitbucket.Response<Bitbucket.Schema.Error>>;
    deletePipelineKnownHost(params: Bitbucket.Params.RepositoriesDeletePipelineKnownHost, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deletePipelineSchedule(params: Bitbucket.Params.RepositoriesDeletePipelineSchedule, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deletePipelineSshKeyPair(params: Bitbucket.Params.RepositoriesDeletePipelineSshKeyPair, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deletePipelineVariable(params: Bitbucket.Params.RepositoriesDeletePipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deletePullRequestApproval(params: Bitbucket.Params.RepositoriesDeletePullRequestApproval, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deletePullRequestComment(params: Bitbucket.Params.RepositoriesDeletePullRequestComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteTag(params: Bitbucket.Params.RepositoriesDeleteTag, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteWebhook(params: Bitbucket.Params.RepositoriesDeleteWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    get(params: Bitbucket.Params.RepositoriesGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Repository>>): Promise<Bitbucket.Response<Bitbucket.Schema.Repository>>;
    getBranch(params: Bitbucket.Params.RepositoriesGetBranch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Branch>>): Promise<Bitbucket.Response<Bitbucket.Schema.Branch>>;
    getBranchingModel(params: Bitbucket.Params.RepositoriesGetBranchingModel, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.BranchingModel>>): Promise<Bitbucket.Response<Bitbucket.Schema.BranchingModel>>;
    getBranchingModelSettings(params: Bitbucket.Params.RepositoriesGetBranchingModelSettings, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.BranchingModelSettings>>): Promise<Bitbucket.Response<Bitbucket.Schema.BranchingModelSettings>>;
    getBranchRestriction(params: Bitbucket.Params.RepositoriesGetBranchRestriction, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>): Promise<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>;
    getCommit(params: Bitbucket.Params.RepositoriesGetCommit, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Commit>>): Promise<Bitbucket.Response<Bitbucket.Schema.Commit>>;
    getCommitBuildStatus(params: Bitbucket.Params.RepositoriesGetCommitBuildStatus, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>): Promise<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>;
    getCommitComment(params: Bitbucket.Params.RepositoriesGetCommitComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.CommitComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.CommitComment>>;
    getDefaultReviewer(params: Bitbucket.Params.RepositoriesGetDefaultReviewer, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getDeployKey(params: Bitbucket.Params.RepositoriesGetDeployKey, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeployKey>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeployKey>>;
    getDeployment(params: Bitbucket.Params.RepositoriesGetDeployment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Deployment>>): Promise<Bitbucket.Response<Bitbucket.Schema.Deployment>>;
    getDiff(params: Bitbucket.Params.RepositoriesGetDiff, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getDownload(params: Bitbucket.Params.RepositoriesGetDownload, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getEnvironment(params: Bitbucket.Params.RepositoriesGetEnvironment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeploymentEnvironment>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeploymentEnvironment>>;
    getIssue(params: Bitbucket.Params.RepositoriesGetIssue, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Issue>>): Promise<Bitbucket.Response<Bitbucket.Schema.Issue>>;
    getIssueAttachment(params: Bitbucket.Params.RepositoriesGetIssueAttachment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getIssueChange(params: Bitbucket.Params.RepositoriesGetIssueChange, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueChange>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueChange>>;
    getIssueComment(params: Bitbucket.Params.RepositoriesGetIssueComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueComment>>;
    getIssueComponent(params: Bitbucket.Params.RepositoriesGetIssueComponent, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Component>>): Promise<Bitbucket.Response<Bitbucket.Schema.Component>>;
    getIssueExportJobStatus(params: Bitbucket.Params.RepositoriesGetIssueExportJobStatus, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueJobStatus>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueJobStatus>>;
    getIssueImportJobStatus(params: Bitbucket.Params.RepositoriesGetIssueImportJobStatus, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueJobStatus>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueJobStatus>>;
    getIssueMilestone(params: Bitbucket.Params.RepositoriesGetIssueMilestone, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Milestone>>): Promise<Bitbucket.Response<Bitbucket.Schema.Milestone>>;
    getIssueVersion(params: Bitbucket.Params.RepositoriesGetIssueVersion, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Version>>): Promise<Bitbucket.Response<Bitbucket.Schema.Version>>;
    getIssueVote(params: Bitbucket.Params.RepositoriesGetIssueVote, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Error>>): Promise<Bitbucket.Response<Bitbucket.Schema.Error>>;
    getIssueWatch(params: Bitbucket.Params.RepositoriesGetIssueWatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Error>>): Promise<Bitbucket.Response<Bitbucket.Schema.Error>>;
    getPatch(params: Bitbucket.Params.RepositoriesGetPatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getPipeline(params: Bitbucket.Params.RepositoriesGetPipeline, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pipeline>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pipeline>>;
    getPipelineConfig(params: Bitbucket.Params.RepositoriesGetPipelineConfig, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelinesConfig>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelinesConfig>>;
    getPipelineKnownHost(params: Bitbucket.Params.RepositoriesGetPipelineKnownHost, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>;
    getPipelineSchedule(params: Bitbucket.Params.RepositoriesGetPipelineSchedule, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>;
    getPipelineSshKeyPair(params: Bitbucket.Params.RepositoriesGetPipelineSshKeyPair, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineSshKeyPair>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineSshKeyPair>>;
    getPipelineStep(params: Bitbucket.Params.RepositoriesGetPipelineStep, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineStep>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineStep>>;
    getPipelineStepLog(params: Bitbucket.Params.RepositoriesGetPipelineStepLog, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getPipelineVariable(params: Bitbucket.Params.RepositoriesGetPipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    getPullRequest(params: Bitbucket.Params.RepositoriesGetPullRequest, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>;
    getPullRequestComment(params: Bitbucket.Params.RepositoriesGetPullRequestComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>;
    getPullRequestDiff(params: Bitbucket.Params.RepositoriesGetPullRequestDiff, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getPullRequestDiffStat(params: Bitbucket.Params.RepositoriesGetPullRequestDiffStat, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getPullRequestPatch(params: Bitbucket.Params.RepositoriesGetPullRequestPatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getTag(params: Bitbucket.Params.RepositoriesGetTag, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Tag>>): Promise<Bitbucket.Response<Bitbucket.Schema.Tag>>;
    getWebhook(params: Bitbucket.Params.RepositoriesGetWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    list(params: Bitbucket.Params.RepositoriesList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositories>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositories>>;
    listBranches(params: Bitbucket.Params.RepositoriesListBranches, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedBranches>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedBranches>>;
    listBranchRestrictions(params: Bitbucket.Params.RepositoriesListBranchRestrictions, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedBranchrestrictions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedBranchrestrictions>>;
    listCommitComments(params: Bitbucket.Params.RepositoriesListCommitComments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitComments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitComments>>;
    listCommits(params: Bitbucket.Params.RepositoriesListCommits, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listCommitsAlt(params: Bitbucket.Params.RepositoriesListCommitsAlt, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listCommitsAt(params: Bitbucket.Params.RepositoriesListCommitsAt, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listCommitsAtAlt(params: Bitbucket.Params.RepositoriesListCommitsAtAlt, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listCommitStatuses(params: Bitbucket.Params.RepositoriesListCommitStatuses, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitstatuses>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitstatuses>>;
    listComponents(params: Bitbucket.Params.RepositoriesListComponents, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedComponents>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedComponents>>;
    listDefaultReviewers(params: Bitbucket.Params.RepositoriesListDefaultReviewers, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listDeployKeys(params: Bitbucket.Params.RepositoriesListDeployKeys, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedDeployKeys>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedDeployKeys>>;
    listDeployments(params: Bitbucket.Params.RepositoriesListDeployments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedDeployments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedDeployments>>;
    listDeploymentVariables(params: Bitbucket.Params.RepositoriesListDeploymentVariables, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedDeploymentVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedDeploymentVariable>>;
    listDiffStats(params: Bitbucket.Params.RepositoriesListDiffStats, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedDiffstats>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedDiffstats>>;
    listDownloads(params: Bitbucket.Params.RepositoriesListDownloads, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listEnvironments(params: Bitbucket.Params.RepositoriesListEnvironments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedEnvironments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedEnvironments>>;
    listFileHistory(params: Bitbucket.Params.RepositoriesListFileHistory, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedFiles>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedFiles>>;
    listForks(params: Bitbucket.Params.RepositoriesListForks, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositories>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositories>>;
    listIssueAttachments(params: Bitbucket.Params.RepositoriesListIssueAttachments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedIssueAttachments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedIssueAttachments>>;
    listIssueChanges(params: Bitbucket.Params.RepositoriesListIssueChanges, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedLogEntries>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedLogEntries>>;
    listIssueComments(params: Bitbucket.Params.RepositoriesListIssueComments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedIssueComments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedIssueComments>>;
    listIssues(params: Bitbucket.Params.RepositoriesListIssues, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedIssues>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedIssues>>;
    listMilestones(params: Bitbucket.Params.RepositoriesListMilestones, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedMilestones>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedMilestones>>;
    listPermissions(params: Bitbucket.Params.RepositoriesListPermissions, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositoryPermissions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositoryPermissions>>;
    listPipelineKnownHosts(params: Bitbucket.Params.RepositoriesListPipelineKnownHosts, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineKnownHosts>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineKnownHosts>>;
    listPipelines(params: Bitbucket.Params.RepositoriesListPipelines, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelines>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelines>>;
    listPipelineScheduleExecutions(params: Bitbucket.Params.RepositoriesListPipelineScheduleExecutions, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineScheduleExecutions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineScheduleExecutions>>;
    listPipelineSchedules(params: Bitbucket.Params.RepositoriesListPipelineSchedules, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineSchedules>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineSchedules>>;
    listPipelineSteps(params: Bitbucket.Params.RepositoriesListPipelineSteps, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineSteps>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineSteps>>;
    listPipelineVariables(params: Bitbucket.Params.RepositoriesListPipelineVariables, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>;
    listPublic(params: Bitbucket.Params.RepositoriesListPublic, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositories>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositories>>;
    listPullRequestActivities(params: Bitbucket.Params.RepositoriesListPullRequestActivities, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listPullRequestActivitiesForRepo(params: Bitbucket.Params.RepositoriesListPullRequestActivitiesForRepo, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listPullRequestComments(params: Bitbucket.Params.RepositoriesListPullRequestComments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequestComments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequestComments>>;
    listPullRequestCommits(params: Bitbucket.Params.RepositoriesListPullRequestCommits, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listPullRequests(params: Bitbucket.Params.RepositoriesListPullRequests, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequests>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequests>>;
    listPullrequestsForCommit(params: Bitbucket.Params.RepositoriesListPullrequestsForCommit, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequests>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPullrequests>>;
    listPullRequestStatuses(params: Bitbucket.Params.RepositoriesListPullRequestStatuses, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitstatuses>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedCommitstatuses>>;
    listRefs(params: Bitbucket.Params.RepositoriesListRefs, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedRefs>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedRefs>>;
    listTags(params: Bitbucket.Params.RepositoriesListTags, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedTags>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedTags>>;
    listVersions(params: Bitbucket.Params.RepositoriesListVersions, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedVersions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedVersions>>;
    listWatchers(params: Bitbucket.Params.RepositoriesListWatchers, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listWebhooks(params: Bitbucket.Params.RepositoriesListWebhooks, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>;
    mergePullRequest(params: Bitbucket.Params.RepositoriesMergePullRequest, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>;
    readSrc(params: Bitbucket.Params.RepositoriesReadSrc, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedTreeentries>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedTreeentries>>;
    readSrcRoot(params: Bitbucket.Params.RepositoriesReadSrcRoot, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedTreeentries>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedTreeentries>>;
    stopPipeline(params: Bitbucket.Params.RepositoriesStopPipeline, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    update(params: Bitbucket.Params.RepositoriesUpdate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Repository>>): Promise<Bitbucket.Response<Bitbucket.Schema.Repository>>;
    updateBranchingModelSettings(params: Bitbucket.Params.RepositoriesUpdateBranchingModelSettings, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.BranchingModelSettings>>): Promise<Bitbucket.Response<Bitbucket.Schema.BranchingModelSettings>>;
    updateBranchRestriction(params: Bitbucket.Params.RepositoriesUpdateBranchRestriction, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>): Promise<Bitbucket.Response<Bitbucket.Schema.Branchrestriction>>;
    updateCommitBuildStatus(params: Bitbucket.Params.RepositoriesUpdateCommitBuildStatus, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>): Promise<Bitbucket.Response<Bitbucket.Schema.Commitstatus>>;
    updateDeployKey(params: Bitbucket.Params.RepositoriesUpdateDeployKey, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeployKey>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeployKey>>;
    updateDeploymentVariable(params: Bitbucket.Params.RepositoriesUpdateDeploymentVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.DeploymentVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.DeploymentVariable>>;
    updateEnvironment(params: Bitbucket.Params.RepositoriesUpdateEnvironment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    updateIssue(params: Bitbucket.Params.RepositoriesUpdateIssue, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Issue>>): Promise<Bitbucket.Response<Bitbucket.Schema.Issue>>;
    updateIssueComment(params: Bitbucket.Params.RepositoriesUpdateIssueComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.IssueComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.IssueComment>>;
    updatePipelineBuildNumber(params: Bitbucket.Params.RepositoriesUpdatePipelineBuildNumber, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineBuildNumber>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineBuildNumber>>;
    updatePipelineConfig(params: Bitbucket.Params.RepositoriesUpdatePipelineConfig, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelinesConfig>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelinesConfig>>;
    updatePipelineKnownHost(params: Bitbucket.Params.RepositoriesUpdatePipelineKnownHost, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineKnownHost>>;
    updatePipelineSchedule(params: Bitbucket.Params.RepositoriesUpdatePipelineSchedule, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineSchedule>>;
    updatePipelineSshKeyPair(params: Bitbucket.Params.RepositoriesUpdatePipelineSshKeyPair, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineSshKeyPair>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineSshKeyPair>>;
    updatePipelineVariable(params: Bitbucket.Params.RepositoriesUpdatePipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    updatePullRequest(params: Bitbucket.Params.RepositoriesUpdatePullRequest, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>): Promise<Bitbucket.Response<Bitbucket.Schema.Pullrequest>>;
    updatePullRequestComment(params: Bitbucket.Params.RepositoriesUpdatePullRequestComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.PullrequestComment>>;
    updateWebhook(params: Bitbucket.Params.RepositoriesUpdateWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
  };
  search: {
    codeOfTeam(params: Bitbucket.Params.SearchCodeOfTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.SearchResultPage>>): Promise<Bitbucket.Response<Bitbucket.Schema.SearchResultPage>>;
    codeOfUser(params: Bitbucket.Params.SearchCodeOfUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.SearchResultPage>>): Promise<Bitbucket.Response<Bitbucket.Schema.SearchResultPage>>;
  };
  snippet: {
    getRawFiles(params: Bitbucket.Params.SnippetGetRawFiles, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
  };
  snippets: {
    checkWatch(params: Bitbucket.Params.SnippetsCheckWatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    create(params: Bitbucket.Params.SnippetsCreate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Snippet>>): Promise<Bitbucket.Response<Bitbucket.Schema.Snippet>>;
    createComment(params: Bitbucket.Params.SnippetsCreateComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Snippet>>): Promise<Bitbucket.Response<Bitbucket.Schema.Snippet>>;
    createForUser(params: Bitbucket.Params.SnippetsCreateForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Snippet>>): Promise<Bitbucket.Response<Bitbucket.Schema.Snippet>>;
    delete(params: Bitbucket.Params.SnippetsDelete, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteAt(params: Bitbucket.Params.SnippetsDeleteAt, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteComment(params: Bitbucket.Params.SnippetsDeleteComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    get(params: Bitbucket.Params.SnippetsGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Snippet>>): Promise<Bitbucket.Response<Bitbucket.Schema.Snippet>>;
    getAt(params: Bitbucket.Params.SnippetsGetAt, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Snippet>>): Promise<Bitbucket.Response<Bitbucket.Schema.Snippet>>;
    getComment(params: Bitbucket.Params.SnippetsGetComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.SnippetComment>>): Promise<Bitbucket.Response<Bitbucket.Schema.SnippetComment>>;
    getCommit(params: Bitbucket.Params.SnippetsGetCommit, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.SnippetCommit>>): Promise<Bitbucket.Response<Bitbucket.Schema.SnippetCommit>>;
    getDiff(params: Bitbucket.Params.SnippetsGetDiff, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getFile(params: Bitbucket.Params.SnippetsGetFile, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getPatch(params: Bitbucket.Params.SnippetsGetPatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getRawFiles(params: Bitbucket.Params.SnippetsGetRawFiles, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    list(params: Bitbucket.Params.SnippetsList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedSnippets>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedSnippets>>;
    listComments(params: Bitbucket.Params.SnippetsListComments, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedSnippetComments>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedSnippetComments>>;
    listCommits(params: Bitbucket.Params.SnippetsListCommits, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedSnippetCommit>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedSnippetCommit>>;
    listForUser(params: Bitbucket.Params.SnippetsListForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedSnippets>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedSnippets>>;
    listWatchers(params: Bitbucket.Params.SnippetsListWatchers, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedUsers>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedUsers>>;
    startWatch(params: Bitbucket.Params.SnippetsStartWatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    stopWatch(params: Bitbucket.Params.SnippetsStopWatch, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    update(params: Bitbucket.Params.SnippetsUpdate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Snippet>>): Promise<Bitbucket.Response<Bitbucket.Schema.Snippet>>;
    updateAt(params: Bitbucket.Params.SnippetsUpdateAt, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Snippet>>): Promise<Bitbucket.Response<Bitbucket.Schema.Snippet>>;
    updateComment(params: Bitbucket.Params.SnippetsUpdateComment, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
  };
  source: {
    createFileCommit(params: Bitbucket.Params.SourceCreateFileCommit, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listHistory(params: Bitbucket.Params.SourceListHistory, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedFiles>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedFiles>>;
    read(params: Bitbucket.Params.SourceRead, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedTreeentries>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedTreeentries>>;
    readRoot(params: Bitbucket.Params.SourceReadRoot, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedTreeentries>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedTreeentries>>;
  };
  ssh: {
    createKey(params: Bitbucket.Params.SshCreateKey, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.SshAccountKey>>): Promise<Bitbucket.Response<Bitbucket.Schema.SshAccountKey>>;
    deleteKey(params: Bitbucket.Params.Empty, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getKey(params: Bitbucket.Params.Empty, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listKeys(params: Bitbucket.Params.SshListKeys, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedSshUserKeys>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedSshUserKeys>>;
    updateKey(params: Bitbucket.Params.Empty, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
  };
  teams: {
    createPipelineVariable(params: Bitbucket.Params.TeamsCreatePipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    createProject(params: Bitbucket.Params.TeamsCreateProject, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Project>>): Promise<Bitbucket.Response<Bitbucket.Schema.Project>>;
    createWebhook(params: Bitbucket.Params.TeamsCreateWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    deletePipelineVariable(params: Bitbucket.Params.TeamsDeletePipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteProject(params: Bitbucket.Params.TeamsDeleteProject, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteWebhook(params: Bitbucket.Params.TeamsDeleteWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    get(params: Bitbucket.Params.TeamsGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Team>>): Promise<Bitbucket.Response<Bitbucket.Schema.Team>>;
    getAllMembers(params: Bitbucket.Params.TeamsGetAllMembers, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.User>>): Promise<Bitbucket.Response<Bitbucket.Schema.User>>;
    getMembers(params: Bitbucket.Params.TeamsGetMembers, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.User>>): Promise<Bitbucket.Response<Bitbucket.Schema.User>>;
    getPipelineVariable(params: Bitbucket.Params.TeamsGetPipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    getProject(params: Bitbucket.Params.TeamsGetProject, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Project>>): Promise<Bitbucket.Response<Bitbucket.Schema.Project>>;
    getWebhook(params: Bitbucket.Params.TeamsGetWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    list(params: Bitbucket.Params.TeamsList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedTeams>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedTeams>>;
    listFollowers(params: Bitbucket.Params.TeamsListFollowers, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedUsers>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedUsers>>;
    listFollowing(params: Bitbucket.Params.TeamsListFollowing, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedUsers>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedUsers>>;
    listPermissions(params: Bitbucket.Params.TeamsListPermissions, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedTeamPermissions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedTeamPermissions>>;
    listPermissionsForRepo(params: Bitbucket.Params.TeamsListPermissionsForRepo, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositoryPermissions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositoryPermissions>>;
    listPermissionsForRepos(params: Bitbucket.Params.TeamsListPermissionsForRepos, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositoryPermissions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositoryPermissions>>;
    listPipelineVariables(params: Bitbucket.Params.TeamsListPipelineVariables, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>;
    listProjects(params: Bitbucket.Params.TeamsListProjects, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedProjects>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedProjects>>;
    listRepositories(params: Bitbucket.Params.TeamsListRepositories, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listRepositoriesForUser(params: Bitbucket.Params.TeamsListRepositoriesForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listWebhooks(params: Bitbucket.Params.TeamsListWebhooks, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>;
    searchCode(params: Bitbucket.Params.TeamsSearchCode, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.SearchResultPage>>): Promise<Bitbucket.Response<Bitbucket.Schema.SearchResultPage>>;
    updatePipelineVariable(params: Bitbucket.Params.TeamsUpdatePipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    updateProject(params: Bitbucket.Params.TeamsUpdateProject, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Project>>): Promise<Bitbucket.Response<Bitbucket.Schema.Project>>;
    updateWebhook(params: Bitbucket.Params.TeamsUpdateWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
  };
  user: {
    get(params: Bitbucket.Params.Empty, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.User>>): Promise<Bitbucket.Response<Bitbucket.Schema.User>>;
    getEmail(params: Bitbucket.Params.UserGetEmail, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listEmails(params: Bitbucket.Params.UserListEmails, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listPermissionsForRepos(params: Bitbucket.Params.UserListPermissionsForRepos, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositoryPermissions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedRepositoryPermissions>>;
    listPermissionsForTeams(params: Bitbucket.Params.UserListPermissionsForTeams, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedTeamPermissions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedTeamPermissions>>;
  };
  users: {
    createPipelineVariable(params: Bitbucket.Params.UsersCreatePipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    createSshKey(params: Bitbucket.Params.UsersCreateSshKey, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.SshAccountKey>>): Promise<Bitbucket.Response<Bitbucket.Schema.SshAccountKey>>;
    createWebhook(params: Bitbucket.Params.UsersCreateWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    deletePipelineVariable(params: Bitbucket.Params.UsersDeletePipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteSshKey(params: Bitbucket.Params.Empty, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteWebhook(params: Bitbucket.Params.UsersDeleteWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    get(params: Bitbucket.Params.UsersGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.User>>): Promise<Bitbucket.Response<Bitbucket.Schema.User>>;
    getAuthedUser(params: Bitbucket.Params.Empty, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.User>>): Promise<Bitbucket.Response<Bitbucket.Schema.User>>;
    getEmailForAuthedUser(params: Bitbucket.Params.UsersGetEmailForAuthedUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getPipelineVariable(params: Bitbucket.Params.UsersGetPipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    getSshKey(params: Bitbucket.Params.Empty, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    getTeamMembers(params: Bitbucket.Params.UsersGetTeamMembers, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.User>>): Promise<Bitbucket.Response<Bitbucket.Schema.User>>;
    getWebhook(params: Bitbucket.Params.UsersGetWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    listEmailsForAuthedUser(params: Bitbucket.Params.UsersListEmailsForAuthedUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listFollowers(params: Bitbucket.Params.UsersListFollowers, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedUsers>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedUsers>>;
    listFollowing(params: Bitbucket.Params.UsersListFollowing, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedUsers>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedUsers>>;
    listPipelineVariables(params: Bitbucket.Params.UsersListPipelineVariables, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedPipelineVariables>>;
    listRepositories(params: Bitbucket.Params.UsersListRepositories, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listRepositoriesForTeam(params: Bitbucket.Params.UsersListRepositoriesForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    listSshKeys(params: Bitbucket.Params.UsersListSshKeys, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedSshUserKeys>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedSshUserKeys>>;
    listWebhooks(params: Bitbucket.Params.UsersListWebhooks, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>;
    searchCode(params: Bitbucket.Params.UsersSearchCode, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.SearchResultPage>>): Promise<Bitbucket.Response<Bitbucket.Schema.SearchResultPage>>;
    updatePipelineVariable(params: Bitbucket.Params.UsersUpdatePipelineVariable, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>): Promise<Bitbucket.Response<Bitbucket.Schema.PipelineVariable>>;
    updateSshKey(params: Bitbucket.Params.Empty, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    updateWebhook(params: Bitbucket.Params.UsersUpdateWebhook, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
  };
  webhooks: {
    create(params: Bitbucket.Params.WebhooksCreate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    createForTeam(params: Bitbucket.Params.WebhooksCreateForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    createForUser(params: Bitbucket.Params.WebhooksCreateForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    delete(params: Bitbucket.Params.WebhooksDelete, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteForTeam(params: Bitbucket.Params.WebhooksDeleteForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    deleteForUser(params: Bitbucket.Params.WebhooksDeleteForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.Any>>): Promise<Bitbucket.Response<Bitbucket.Schema.Any>>;
    get(params: Bitbucket.Params.WebhooksGet, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    getAllSubjectTypes(params: Bitbucket.Params.Empty, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.SubjectTypes>>): Promise<Bitbucket.Response<Bitbucket.Schema.SubjectTypes>>;
    getForTeam(params: Bitbucket.Params.WebhooksGetForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    getForUser(params: Bitbucket.Params.WebhooksGetForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    list(params: Bitbucket.Params.WebhooksList, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedHookEvents>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedHookEvents>>;
    listForRepo(params: Bitbucket.Params.WebhooksListForRepo, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>;
    listForTeam(params: Bitbucket.Params.WebhooksListForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>;
    listForUser(params: Bitbucket.Params.WebhooksListForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>): Promise<Bitbucket.Response<Bitbucket.Schema.PaginatedWebhookSubscriptions>>;
    update(params: Bitbucket.Params.WebhooksUpdate, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    updateForTeam(params: Bitbucket.Params.WebhooksUpdateForTeam, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
    updateForUser(params: Bitbucket.Params.WebhooksUpdateForUser, callback?: Bitbucket.Callback<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>): Promise<Bitbucket.Response<Bitbucket.Schema.WebhookSubscription>>;
  };
}

export = Bitbucket;

export as namespace Bitbucket;
